@@ -185,7 +185,7 @@ function _configure_octavia_apache_wsgi {
 }
 
 function _configure_octavia_apache_uwsgi {
-    write_uwsgi_config "$OCTAVIA_UWSGI_CONF" "$OCTAVIA_UWSGI_APP" "/$OCTAVIA_SERVICE_TYPE"
+    write_uwsgi_config "$OCTAVIA_UWSGI_CONF" "$OCTAVIA_UWSGI_APP" "/$OCTAVIA_SERVICE_TYPE" "" "octavia-wsgi"
 }
 
 
@@ -596,7 +596,7 @@ function create_amphora_flavor {
         disk_size=$((disk_size + 1))
     fi
     # Pass even if it exists to avoid race condition on multinode
-    openstack flavor create --id auto --ram 1024 --disk $disk_size --vcpus 1 --private m1.amphora -f value -c id --property hw_rng:allowed=True || true
+    openstack flavor create --ram 1024 --disk $disk_size --vcpus 1 --private m1.amphora -f value -c id --property hw_rng:allowed=True || true
     amp_flavor_id=$(openstack flavor show m1.amphora -f value -c id)
     iniset $OCTAVIA_CONF controller_worker amp_flavor_id $amp_flavor_id
 }
@@ -621,11 +621,26 @@ function configure_octavia_api_haproxy {
 }
 
 function configure_rsyslog {
+    sudo mkdir -m 775 /var/log/octavia
+    sudo chgrp syslog /var/log/octavia
+
     sudo cp ${OCTAVIA_DIR}/devstack/etc/rsyslog/10-octavia-log-offloading.conf /etc/rsyslog.d/
     sudo sed -e "
         s|%ADMIN_PORT%|${OCTAVIA_AMP_LOG_ADMIN_PORT}|g;
         s|%TENANT_PORT%|${OCTAVIA_AMP_LOG_TENANT_PORT}|g;
     " -i /etc/rsyslog.d/10-octavia-log-offloading.conf
+
+    # Temporary backward compatibility symbolic link.
+    # Remove in the next "I" cycle
+    sudo touch /var/log/octavia/octavia-tenant-traffic.log
+    sudo chmod 664 /var/log/octavia/octavia-tenant-traffic.log
+    sudo chgrp syslog /var/log/octavia/octavia-tenant-traffic.log
+    sudo ln -s /var/log/octavia/octavia-tenant-traffic.log /var/log/octavia-tenant-traffic.log
+
+    sudo touch /var/log/octavia/octavia-amphora.log
+    sudo chmod 664 /var/log/octavia/octavia-amphora.log
+    sudo chgrp syslog /var/log/octavia/octavia-amphora.log
+    sudo ln -s /var/log/octavia/octavia-amphora.log /var/log/octavia-amphora.log
 }
 
 function octavia_start {
