@@ -20,17 +20,18 @@ set -e
 usage() {
     echo
     echo "Usage: $(basename "$0")"
-    echo "            [-a i386 | **amd64** | armhf | aarch64 | ppc64le]"
+    echo "            [-a **amd64** | armhf | aarch64 | ppc64le]"
     echo "            [-b **haproxy** ]"
     echo "            [-c **~/.cache/image-create** | <cache directory> ]"
-    echo "            [-d **focal**/**9-stream**/**9** | <other release id> ]"
+    echo "            [-d **noble**/**9-stream**/**9** | <other release id> ]"
     echo "            [-e]"
     echo "            [-f]"
     echo "            [-g **repository branch** | stable/train | stable/stein | ... ]"
     echo "            [-h]"
-    echo "            [-i **ubuntu-minimal** | fedora | centos-minimal | rhel ]"
+    echo "            [-i **ubuntu-minimal** | fedora | centos-minimal | rhel | rocky ]"
     echo "            [-k <kernel package name> ]"
     echo "            [-l <log file> ]"
+    echo "            [-m]"
     echo "            [-n]"
     echo "            [-o **amphora-x64-haproxy.qcow2** | <filename> ]"
     echo "            [-p]"
@@ -44,7 +45,7 @@ usage() {
     echo "        '-a' is the architecture type for the image (default: amd64)"
     echo "        '-b' is the backend type (default: haproxy)"
     echo "        '-c' is the path to the cache directory (default: ~/.cache/image-create)"
-    echo "        '-d' distribution release id (default on ubuntu: focal)"
+    echo "        '-d' distribution release id (default on ubuntu: noble)"
     echo "        '-e' enable complete mandatory access control systems when available (default: permissive)"
     echo "        '-f' disable tmpfs for build"
     echo "        '-g' build the image for a specific OpenStack Git branch (default: current repository branch)"
@@ -52,6 +53,7 @@ usage() {
     echo "        '-i' is the base OS (default: ubuntu-minimal)"
     echo "        '-k' is the kernel meta package name, currently only for ubuntu-minimal base OS (default: linux-image-virtual)"
     echo "        '-l' is output logfile (default: none)"
+    echo "        '-m' enable vCPU pinning optimizations (default: disabled)"
     echo "        '-n' disable sshd (default: enabled)"
     echo "        '-o' is the output image file name"
     echo "        '-p' install amphora-agent from distribution packages (default: disabled)"
@@ -92,12 +94,11 @@ dib_enable_tracing=
 
 AMP_LOGFILE=""
 
-while getopts "a:b:c:d:efg:hi:k:l:no:pt:r:s:vw:xy" opt; do
+while getopts "a:b:c:d:efg:hi:k:l:mno:pt:r:s:vw:xy" opt; do
     case $opt in
         a)
             AMP_ARCH=$OPTARG
-            if [ "$AMP_ARCH" != "i386" ] && \
-                [ "$AMP_ARCH" != "amd64" ] && \
+            if [ "$AMP_ARCH" != "amd64" ] && \
                 [ "$AMP_ARCH" != "ppc64le" ] && \
                 [ "$AMP_ARCH" != "aarch64" ] && \
                 [ "$AMP_ARCH" != "armhf" ]; then
@@ -149,6 +150,7 @@ while getopts "a:b:c:d:efg:hi:k:l:no:pt:r:s:vw:xy" opt; do
                 [ "$AMP_BASEOS" != "fedora" ] && \
                 [ "$AMP_BASEOS" != "centos" ] && \
                 [ "$AMP_BASEOS" != "centos-minimal" ] && \
+                [ "$AMP_BASEOS" != "rocky" ] && \
                 [ "$AMP_BASEOS" != "rhel" ]; then
                 echo "Error: Unsupported base OS $AMP_BASEOS specified"
                 exit 3
@@ -159,6 +161,9 @@ while getopts "a:b:c:d:efg:hi:k:l:no:pt:r:s:vw:xy" opt; do
             if [ "$AMP_BASEOS" == "centos" ]; then
                 AMP_BASEOS="centos-minimal"
             fi
+            if [ "$AMP_BASEOS" == "rocky" ]; then
+                AMP_BASEOS="rocky-container"
+            fi
         ;;
         k)
             AMP_KERNEL=$OPTARG
@@ -166,6 +171,9 @@ while getopts "a:b:c:d:efg:hi:k:l:no:pt:r:s:vw:xy" opt; do
         l)
             AMP_LOGFILE="--logfile=$OPTARG"
         ;;
+        m)
+            AMP_ENABLE_CPUPINNING=1
+        ;;
         n)
             AMP_DISABLE_SSHD=1
         ;;
@@ -234,13 +242,15 @@ AMP_CACHEDIR="$( cd "$AMP_CACHEDIR" && pwd )"
 AMP_BASEOS=${AMP_BASEOS:-"ubuntu-minimal"}
 
 if [ "$AMP_BASEOS" = "ubuntu-minimal" ]; then
-    export DIB_RELEASE=${AMP_DIB_RELEASE:-"focal"}
+    export DIB_RELEASE=${AMP_DIB_RELEASE:-"noble"}
 elif [ "${AMP_BASEOS}" = "rhel" ]; then
     export DIB_RELEASE=${AMP_DIB_RELEASE:-"9"}
 elif [ "${AMP_BASEOS}" = "centos-minimal" ]; then
     export DIB_RELEASE=${AMP_DIB_RELEASE:-"9-stream"}
 elif [ "${AMP_BASEOS}" = "fedora" ]; then
     export DIB_RELEASE=${AMP_DIB_RELEASE:-"28"}
+elif [ "${AMP_BASEOS}" = "rocky-container" ]; then
+    export DIB_RELEASE=${AMP_DIB_RELEASE:-"9"}
 fi
 
 AMP_OUTPUTFILENAME=${AMP_OUTPUTFILENAME:-"$PWD/amphora-x64-haproxy.qcow2"}
@@ -253,6 +263,8 @@ if [ "$AMP_BASEOS" = "ubuntu-minimal" ]; then
     export DIB_UBUNTU_KERNEL=${AMP_KERNEL:-"linux-image-virtual"}
 fi
 
+AMP_ENABLE_CPUPINNING=${AMP_ENABLE_CPUPINNING:-0}
+
 AMP_DISABLE_SSHD=${AMP_DISABLE_SSHD:-0}
 
 AMP_PACKAGE_INSTALL=${AMP_PACKAGE_INSTALL:-0}
@@ -298,7 +310,7 @@ else
 fi
 
 # Make sure we have a value set for DIB_OCTAVIA_AMP_USE_NFTABLES
-export DIB_OCTAVIA_AMP_USE_NFTABLES=${DIB_OCTAVIA_AMP_USE_NFTABLES:-False}
+export DIB_OCTAVIA_AMP_USE_NFTABLES=${DIB_OCTAVIA_AMP_USE_NFTABLES:-True}
 
 export CLOUD_INIT_DATASOURCES=${CLOUD_INIT_DATASOURCES:-"ConfigDrive"}
 
@@ -448,7 +460,7 @@ AMP_element_sequence="$AMP_element_sequence cloud-init-datasources"
 AMP_element_sequence="$AMP_element_sequence remove-default-ints"
 
 # SELinux systems
-if [ "${AMP_BASEOS}" = "centos-minimal" ] || [ "${AMP_BASEOS}" = "fedora" ] || [ "${AMP_BASEOS}" = "rhel" ]; then
+if [ "${AMP_BASEOS}" = "centos-minimal" ] || [ "${AMP_BASEOS}" = "fedora" ] || [ "${AMP_BASEOS}" = "rhel" ] || [ "${AMP_BASEOS}" = "rocky-container" ]; then
     if [ "$AMP_ENABLE_FULL_MAC_SECURITY" -ne 1 ]; then
         AMP_element_sequence="$AMP_element_sequence selinux-permissive"
     else
@@ -457,8 +469,13 @@ if [ "${AMP_BASEOS}" = "centos-minimal" ] || [ "${AMP_BASEOS}" = "fedora" ] || [
     fi
 fi
 
+# AppArmor systems
+if [ "${AMP_BASEOS}" = "ubuntu-minimal" ] || [ "${AMP_BASEOS}" = "ubuntu" ]; then
+    AMP_element_sequence="$AMP_element_sequence amphora-apparmor"
+fi
+
 # Disable the dnf makecache timer
-if [ "${AMP_BASEOS}" = "centos-minimal" ] || [ "${AMP_BASEOS}" = "fedora" ] || [ "${AMP_BASEOS}" = "rhel" ]; then
+if [ "${AMP_BASEOS}" = "centos-minimal" ] || [ "${AMP_BASEOS}" = "fedora" ] || [ "${AMP_BASEOS}" = "rhel" ] || [ "${AMP_BASEOS}" = "rocky-container" ]; then
     AMP_element_sequence="$AMP_element_sequence disable-makecache"
 fi
 
@@ -476,9 +493,17 @@ AMP_element_sequence="$AMP_element_sequence pip-cache"
 # Add certificate ramfs element
 AMP_element_sequence="$AMP_element_sequence certs-ramfs"
 
+# Add cpu-pinning element
+if [ "$AMP_ENABLE_CPUPINNING" -eq 1 ]; then
+    AMP_element_sequence="$AMP_element_sequence cpu-pinning"
+fi
+
 # Disable SSHD if requested
 if [ "$AMP_DISABLE_SSHD" -eq 1 ]; then
     AMP_element_sequence="$AMP_element_sequence remove-sshd"
+    export DIB_OCTAVIA_AMP_USE_SSH=${DIB_OCTAVIA_AMP_USE_SSH:-False}
+else
+    export DIB_OCTAVIA_AMP_USE_SSH=${DIB_OCTAVIA_AMP_USE_SSH:-True}
 fi
 
 # Enable FIPS if requested
