@@ -38,8 +38,6 @@ LOG = logging.getLogger(__name__)
 
 j2_env = jinja2.Environment(autoescape=True, loader=jinja2.FileSystemLoader(
     os.path.dirname(os.path.realpath(__file__)) + consts.AGENT_API_TEMPLATES))
-UPSTART_TEMPLATE = j2_env.get_template(consts.KEEPALIVED_JINJA2_UPSTART)
-SYSVINIT_TEMPLATE = j2_env.get_template(consts.KEEPALIVED_JINJA2_SYSVINIT)
 SYSTEMD_TEMPLATE = j2_env.get_template(consts.KEEPALIVED_JINJA2_SYSTEMD)
 check_script_file_template = j2_env.get_template(
     consts.KEEPALIVED_CHECK_SCRIPT)
@@ -92,32 +90,18 @@ class KeepalivedLvs(lvs_listener_base.LvsListenerApiServerBase):
                 f.write(b)
                 b = stream.read(BUFFER)
 
-        init_system = util.get_os_init_system()
+        file_path = util.keepalived_lvs_init_path(listener_id)
 
-        file_path = util.keepalived_lvs_init_path(init_system, listener_id)
+        template = SYSTEMD_TEMPLATE
 
-        if init_system == consts.INIT_SYSTEMD:
-            template = SYSTEMD_TEMPLATE
-
-            # Render and install the network namespace systemd service
-            util.install_netns_systemd_service()
-            util.run_systemctl_command(
-                consts.ENABLE, consts.AMP_NETNS_SVC_PREFIX)
-        elif init_system == consts.INIT_UPSTART:
-            template = UPSTART_TEMPLATE
-        elif init_system == consts.INIT_SYSVINIT:
-            template = SYSVINIT_TEMPLATE
-        else:
-            raise util.UnknownInitError()
+        # Render and install the network namespace systemd service
+        util.install_netns_systemd_service()
+        util.run_systemctl_command(
+            consts.ENABLE, consts.AMP_NETNS_SVC_PREFIX, False)
 
         # Render and install the keepalivedlvs init script
-        if init_system == consts.INIT_SYSTEMD:
-            # mode 00644
-            mode = stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP | stat.S_IROTH
-        else:
-            # mode 00755
-            mode = (stat.S_IRWXU | stat.S_IRGRP | stat.S_IXGRP |
-                    stat.S_IROTH | stat.S_IXOTH)
+        # mode 00644
+        mode = stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP | stat.S_IROTH
         keepalived_pid, vrrp_pid, check_pid = util.keepalived_lvs_pids_path(
             listener_id)
         if not os.path.exists(file_path):
@@ -136,22 +120,15 @@ class KeepalivedLvs(lvs_listener_base.LvsListenerApiServerBase):
                 text_file.write(text)
 
         # Make sure the keepalivedlvs service is enabled on boot
-        if init_system == consts.INIT_SYSTEMD:
+        try:
             util.run_systemctl_command(
-                consts.ENABLE, "octavia-keepalivedlvs-%s" % str(listener_id))
-        elif init_system == consts.INIT_SYSVINIT:
-            init_enable_cmd = "insserv {file}".format(file=file_path)
-            try:
-                subprocess.check_output(init_enable_cmd.split(),
-                                        stderr=subprocess.STDOUT)
-            except subprocess.CalledProcessError as e:
-                LOG.debug('Failed to enable '
-                          'octavia-keepalivedlvs service: '
-                          '%(err)s', {'err': str(e)})
-                return webob.Response(json={
-                    'message': ("Error enabling "
-                                "octavia-keepalivedlvs service"),
-                    'details': e.output}, status=500)
+                consts.ENABLE,
+                consts.KEEPALIVEDLVS_SYSTEMD % listener_id)
+        except subprocess.CalledProcessError as e:
+            return webob.Response(json={
+                'message': ("Error enabling "
+                            "octavia-keepalivedlvs service"),
+                'details': e.output}, status=500)
 
         if NEED_CHECK:
             # inject the check script for keepalived process
@@ -165,7 +142,6 @@ class KeepalivedLvs(lvs_listener_base.LvsListenerApiServerBase):
                                'w') as script_file:
                     text = check_script_file_template.render(
                         consts=consts,
-                        init_system=init_system,
                         keepalived_lvs_pid_dir=util.keepalived_lvs_dir()
                     )
                     script_file.write(text)
@@ -180,8 +156,8 @@ class KeepalivedLvs(lvs_listener_base.LvsListenerApiServerBase):
             raise exceptions.HTTPException(
                 response=webob.Response(json={
                     'message': 'UDP Listener Not Found',
-                    'details': "No UDP listener with UUID: {0}".format(
-                        listener_id)}, status=404))
+                    'details': f"No UDP listener with UUID: {listener_id}"},
+                    status=404))
 
     def get_lvs_listener_config(self, listener_id):
         """Gets the keepalivedlvs config
@@ -190,7 +166,7 @@ class KeepalivedLvs(lvs_listener_base.LvsListenerApiServerBase):
         """
         self._check_lvs_listener_exists(listener_id)
         with open(util.keepalived_lvs_cfg_path(listener_id),
-                  'r', encoding='utf-8') as file:
+                  encoding='utf-8') as file:
             cfg = file.read()
             resp = webob.Response(cfg, content_type='text/plain')
             return resp
@@ -202,7 +178,7 @@ class KeepalivedLvs(lvs_listener_base.LvsListenerApiServerBase):
                           consts.AMP_ACTION_RELOAD]:
             return webob.Response(json={
                 'message': 'Invalid Request',
-                'details': "Unknown action: {0}".format(action)}, status=400)
+                'details': f"Unknown action: {action}"}, status=400)
 
         # When octavia requests a reload of keepalived, force a restart since
         # a keepalived reload doesn't restore members in their initial state.
@@ -216,18 +192,13 @@ class KeepalivedLvs(lvs_listener_base.LvsListenerApiServerBase):
             if consts.OFFLINE == self._check_lvs_listener_status(listener_id):
                 action = consts.AMP_ACTION_START
 
-        cmd = ("/usr/sbin/service "
-               "octavia-keepalivedlvs-{listener_id} "
-               "{action}".format(listener_id=listener_id, action=action))
-
         try:
-            subprocess.check_output(cmd.split(), stderr=subprocess.STDOUT)
+            util.run_systemctl_command(
+                action, consts.KEEPALIVEDLVS_SYSTEMD % listener_id)
         except subprocess.CalledProcessError as e:
-            LOG.debug('Failed to %s keepalivedlvs listener %s',
-                      listener_id + ' : ' + action, str(e))
             return webob.Response(json={
-                'message': ("Failed to {0} keepalivedlvs listener {1}"
-                            .format(action, listener_id)),
+                'message': (f"Failed to {action} keepalivedlvs listener "
+                            f"{listener_id}"),
                 'details': e.output}, status=500)
 
         is_vrrp = (CONF.controller_worker.loadbalancer_topology ==
@@ -241,9 +212,8 @@ class KeepalivedLvs(lvs_listener_base.LvsListenerApiServerBase):
 
         return webob.Response(
             json={'message': 'OK',
-                  'details': 'keepalivedlvs listener {listener_id} '
-                             '{action}ed'.format(listener_id=listener_id,
-                                                 action=action)},
+                  'details': (f'keepalivedlvs listener {listener_id} '
+                              f'{action}ed')},
             status=202)
 
     def _check_lvs_listener_status(self, listener_id):
@@ -252,7 +222,7 @@ class KeepalivedLvs(lvs_listener_base.LvsListenerApiServerBase):
                     '/proc', util.get_keepalivedlvs_pid(listener_id))):
                 # Check if the listener is disabled
                 with open(util.keepalived_lvs_cfg_path(listener_id),
-                          'r', encoding='utf-8') as file:
+                          encoding='utf-8') as file:
                     cfg = file.read()
                     m = re.search('virtual_server', cfg)
                     if m:
@@ -289,12 +259,12 @@ class KeepalivedLvs(lvs_listener_base.LvsListenerApiServerBase):
         if os.path.exists(keepalived_pid) and os.path.exists(
                 os.path.join('/proc',
                              util.get_keepalivedlvs_pid(listener_id))):
-            cmd = ("/usr/sbin/service "
-                   "octavia-keepalivedlvs-{0} stop".format(listener_id))
             try:
-                subprocess.check_output(cmd.split(), stderr=subprocess.STDOUT)
+                util.run_systemctl_command(
+                    consts.STOP,
+                    consts.KEEPALIVEDLVS_SYSTEMD % listener_id)
             except subprocess.CalledProcessError as e:
-                LOG.error("Failed to stop keepalivedlvs service: %s", str(e))
+                LOG.error("Failed to stop keepalivedlvs service: %s", e)
                 return webob.Response(json={
                     'message': "Error stopping keepalivedlvs",
                     'details': e.output}, status=500)
@@ -309,30 +279,21 @@ class KeepalivedLvs(lvs_listener_base.LvsListenerApiServerBase):
                 os.remove(pid)
 
         # disable the service
-        init_system = util.get_os_init_system()
-        init_path = util.keepalived_lvs_init_path(init_system, listener_id)
+        init_path = util.keepalived_lvs_init_path(listener_id)
 
-        if init_system == consts.INIT_SYSTEMD:
+        try:
             util.run_systemctl_command(
-                consts.DISABLE, "octavia-keepalivedlvs-%s" % str(listener_id))
-        elif init_system == consts.INIT_SYSVINIT:
-            init_disable_cmd = "insserv -r {file}".format(file=init_path)
-        elif init_system != consts.INIT_UPSTART:
-            raise util.UnknownInitError()
-
-        if init_system == consts.INIT_SYSVINIT:
-            try:
-                subprocess.check_output(init_disable_cmd.split(),
-                                        stderr=subprocess.STDOUT)
-            except subprocess.CalledProcessError as e:
-                LOG.error("Failed to disable "
-                          "octavia-keepalivedlvs-%(list)s service: "
-                          "%(err)s", {'list': listener_id, 'err': str(e)})
-                return webob.Response(json={
-                    'message': (
-                        "Error disabling octavia-keepalivedlvs-"
-                        "{0} service".format(listener_id)),
-                    'details': e.output}, status=500)
+                consts.DISABLE,
+                consts.KEEPALIVEDLVS_SYSTEMD % listener_id)
+        except subprocess.CalledProcessError as e:
+            LOG.error("Failed to disable "
+                      "octavia-keepalivedlvs-%(list)s service: "
+                      "%(err)s", {'list': listener_id, 'err': str(e)})
+            return webob.Response(json={
+                'message': (
+                    f"Error disabling octavia-keepalivedlvs-{listener_id} "
+                    "service"),
+                'details': e.output}, status=500)
 
         # delete init script ,config file and log file for that listener
         if os.path.exists(init_path):
