@@ -29,7 +29,7 @@ CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 
 
-class BaseOS(object):
+class BaseOS:
 
     def __init__(self, os_name):
         self.os_name = os_name
@@ -64,21 +64,24 @@ class BaseOS(object):
         interface.write()
 
     def write_vip_interface_file(self, interface, vips, mtu, vrrp_info,
-                                 fixed_ips=None):
+                                 fixed_ips=None, is_sriov=False):
         vip_interface = interface_file.VIPInterfaceFile(
             name=interface,
             mtu=mtu,
             vips=vips,
             vrrp_info=vrrp_info,
             fixed_ips=fixed_ips,
-            topology=CONF.controller_worker.loadbalancer_topology)
+            topology=CONF.controller_worker.loadbalancer_topology,
+            is_sriov=is_sriov)
         vip_interface.write()
 
-    def write_port_interface_file(self, interface, fixed_ips, mtu):
+    def write_port_interface_file(self, interface, fixed_ips, mtu,
+                                  is_sriov=False):
         port_interface = interface_file.PortInterfaceFile(
             name=interface,
             mtu=mtu,
-            fixed_ips=fixed_ips)
+            fixed_ips=fixed_ips,
+            is_sriov=is_sriov)
         port_interface.write()
 
     @classmethod
@@ -88,15 +91,16 @@ class BaseOS(object):
         LOG.debug("Executing: %s", cmd)
         try:
             out = subprocess.check_output(cmd.split(),
-                                          stderr=subprocess.STDOUT)
-            for line in out.decode('utf-8').split('\n'):
+                                          stderr=subprocess.STDOUT,
+                                          encoding='utf-8')
+            for line in out.split('\n'):
                 LOG.debug(line)
         except subprocess.CalledProcessError as e:
             LOG.error('Failed to set up %s due to error: %s %s', interface,
                       e, e.output)
             raise exceptions.HTTPException(
                 response=webob.Response(json={
-                    'message': 'Error plugging {0}'.format(name),
+                    'message': f'Error plugging {name}',
                     'details': e.output}, status=500))
 
 
@@ -108,18 +112,18 @@ class Ubuntu(BaseOS):
 
     def cmd_get_version_of_installed_package(self, package_name):
         name = self._map_package_name(package_name)
-        return "dpkg-query -W -f=${{Version}} {name}".format(name=name)
+        return f"dpkg-query -W -f=${{Version}} {name}"
 
 
 class RH(BaseOS):
 
     @classmethod
     def is_os_name(cls, os_name):
-        return os_name in ['fedora', 'rhel']
+        return os_name in ['fedora', 'rhel', 'rocky']
 
     def cmd_get_version_of_installed_package(self, package_name):
         name = self._map_package_name(package_name)
-        return "rpm -q --queryformat %{{VERSION}} {name}".format(name=name)
+        return f"rpm -q --queryformat %{{VERSION}} {name}"
 
 
 class CentOS(RH):
