@@ -19,7 +19,7 @@ from typing import Optional
 from octavia.db import models as db_models
 
 
-class AmphoraLoadBalancerDriver(object, metaclass=abc.ABCMeta):
+class AmphoraLoadBalancerDriver(metaclass=abc.ABCMeta):
     @abc.abstractmethod
     def update_amphora_listeners(self, loadbalancer, amphora,
                                  timeout_dict):
@@ -252,8 +252,19 @@ class AmphoraLoadBalancerDriver(object, metaclass=abc.ABCMeta):
         :raises TimeOutException: The amphora didn't reply
         """
 
+    @abc.abstractmethod
+    def set_interface_rules(self, amphora: db_models.Amphora, ip_address,
+                            rules):
+        """Sets interface firewall rules in the amphora
 
-class VRRPDriverMixin(object, metaclass=abc.ABCMeta):
+        :param amphora: The amphora to query.
+        :param ip_address: The IP address assigned to the interface the rules
+                           will be applied on.
+        :param rules: The l1st of allow rules to apply.
+        """
+
+
+class VRRPDriverMixin(metaclass=abc.ABCMeta):
     """Abstract mixin class for VRRP support in loadbalancer amphorae
 
     Usage: To plug VRRP support in another service driver XYZ, use:
