@@ -12,7 +12,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from cryptography import fernet
 from jsonschema import exceptions as js_exceptions
 from jsonschema import validate
 
@@ -71,13 +70,12 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
             topic=consts.TOPIC_AMPHORA_V2, version="2.0", fanout=False)
         self.client = rpc.get_client(self.target)
         self.repositories = repositories.Repositories()
-        key = utils.get_compatible_server_certs_key_passphrase()
-        self.fernet = fernet.Fernet(key)
+        self.fernet = utils.get_server_certs_key_passphrases_fernet()
 
     def _validate_pool_algorithm(self, pool):
         if pool.lb_algorithm not in AMPHORA_SUPPORTED_LB_ALGORITHMS:
-            msg = ('Amphora provider does not support %s algorithm.'
-                   % pool.lb_algorithm)
+            msg = (f'Amphora provider does not support {pool.lb_algorithm} '
+                   f'algorithm.')
             raise exceptions.UnsupportedOptionError(
                 user_fault_string=msg,
                 operator_fault_string=msg)
@@ -127,6 +125,12 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
 
         try:
             vip, add_vips = network_driver.allocate_vip(lb_obj)
+        except network_base.VIPInUseException as e:
+            message = str(e)
+            if getattr(e, 'orig_msg', None) is not None:
+                message = e.orig_msg
+            raise exceptions.Conflict(user_fault_string=message,
+                                      operator_fault_string=message)
         except network_base.AllocateVIPException as e:
             message = str(e)
             if getattr(e, 'orig_msg', None) is not None:
@@ -273,8 +277,10 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
     # Member
     def member_create(self, member):
         pool_id = member.pool_id
-        db_pool = self.repositories.pool.get(db_apis.get_session(),
-                                             id=pool_id)
+        session = db_apis.get_session()
+        with session.begin():
+            db_pool = self.repositories.pool.get(session,
+                                                 id=pool_id)
         self._validate_members(db_pool, [member])
 
         payload = {consts.MEMBER: member.to_dict()}
@@ -296,7 +302,9 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
 
     def member_batch_update(self, pool_id, members):
         # The DB should not have updated yet, so we can still use the pool
-        db_pool = self.repositories.pool.get(db_apis.get_session(), id=pool_id)
+        session = db_apis.get_session()
+        with session.begin():
+            db_pool = self.repositories.pool.get(session, id=pool_id)
 
         self._validate_members(db_pool, members)
 
@@ -385,8 +393,10 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
 
     # L7 Policy
     def l7policy_create(self, l7policy):
-        db_listener = self.repositories.listener.get(db_apis.get_session(),
-                                                     id=l7policy.listener_id)
+        session = db_apis.get_session()
+        with session.begin():
+            db_listener = self.repositories.listener.get(
+                session, id=l7policy.listener_id)
         if db_listener.protocol not in VALID_L7POLICY_LISTENER_PROTOCOLS:
             msg = ('%s protocol listeners do not support L7 policies' % (
                 db_listener.protocol))
@@ -467,9 +477,9 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
         except js_exceptions.ValidationError as e:
             error_object = ''
             if e.relative_path:
-                error_object = '{} '.format(e.relative_path[0])
+                error_object = f'{e.relative_path[0]} '
             raise exceptions.UnsupportedOptionError(
-                user_fault_string='{0}{1}'.format(error_object, e.message),
+                user_fault_string=f'{error_object}{e.message}',
                 operator_fault_string=str(e))
         except Exception as e:
             raise exceptions.DriverError(
@@ -553,9 +563,9 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
         except js_exceptions.ValidationError as e:
             error_object = ''
             if e.relative_path:
-                error_object = '{} '.format(e.relative_path[0])
+                error_object = f'{e.relative_path[0]} '
             raise exceptions.UnsupportedOptionError(
-                user_fault_string='{0}{1}'.format(error_object, e.message),
+                user_fault_string=f'{error_object}{e.message}',
                 operator_fault_string=str(e))
         except Exception as e:
             raise exceptions.DriverError(
@@ -576,6 +586,18 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
             # when the octavia-lib supports it.
             compute_driver.validate_availability_zone(compute_zone)
 
+        volume_zone = availability_zone_dict.get(consts.VOLUME_ZONE, None)
+        if volume_zone:
+            volume_driver = stevedore_driver.DriverManager(
+                namespace='octavia.volume.drivers',
+                name=CONF.controller_worker.volume_driver,
+                invoke_on_load=True
+            ).driver
+
+            # TODO(johnsom) Fix this to raise a NotFound error
+            # when the octavia-lib supports it.
+            volume_driver.validate_availability_zone(volume_zone)
+
         check_nets = availability_zone_dict.get(
             consts.VALID_VIP_NETWORKS, [])
         management_net = availability_zone_dict.get(
