@@ -23,6 +23,7 @@ from cryptography.hazmat.primitives import serialization
 from cryptography import x509
 from oslo_config import cfg
 from oslo_log import log as logging
+from oslo_utils import timeutils
 
 from octavia.certificates.common import local as local_common
 from octavia.certificates.generator import cert_gen
@@ -45,19 +46,21 @@ class LocalCertGenerator(cert_gen.CertGenerator):
         if not ca_cert:
             LOG.info("Using CA Certificate from config.")
             try:
-                ca_cert = open(CONF.certificates.ca_certificate, 'rb').read()
-            except IOError as e:
+                with open(CONF.certificates.ca_certificate, 'rb') as fp:
+                    fp.read()
+            except OSError as e:
                 raise exceptions.CertificateGenerationException(
-                    msg="Failed to load CA Certificate {0}."
+                    msg="Failed to load CA Certificate {}."
                         .format(CONF.certificates.ca_certificate)
                 ) from e
         if not ca_key:
             LOG.info("Using CA Private Key from config.")
             try:
-                ca_key = open(CONF.certificates.ca_private_key, 'rb').read()
-            except IOError as e:
+                with open(CONF.certificates.ca_private_key, 'rb') as fp:
+                    fp.read()
+            except OSError as e:
                 raise exceptions.CertificateGenerationException(
-                    msg="Failed to load CA Private Key {0}."
+                    msg="Failed to load CA Private Key {}."
                         .format(CONF.certificates.ca_private_key)
                 ) from e
         if not ca_key_pass:
@@ -94,7 +97,7 @@ class LocalCertGenerator(cert_gen.CertGenerator):
             algorithm = getattr(hashes, ca_digest.upper())()
         except AttributeError as e:
             raise crypto_exceptions.UnsupportedAlgorithm(
-                "Supplied digest method not found: %s" % ca_digest
+                f"Supplied digest method not found: {ca_digest}"
             ) from e
 
         if not ca_cert:
@@ -118,8 +121,8 @@ class LocalCertGenerator(cert_gen.CertGenerator):
                                             backend=backends.default_backend())
             new_cert = x509.CertificateBuilder()
             new_cert = new_cert.serial_number(cls._new_serial())
-            valid_from_datetime = datetime.datetime.utcnow()
-            valid_to_datetime = (datetime.datetime.utcnow() +
+            valid_from_datetime = timeutils.utcnow()
+            valid_to_datetime = (timeutils.utcnow() +
                                  datetime.timedelta(seconds=validity))
             new_cert = new_cert.not_valid_before(valid_from_datetime)
             new_cert = new_cert.not_valid_after(valid_to_datetime)
