@@ -18,9 +18,10 @@ import cotyledon
 from cotyledon import oslo_config_glue
 from oslo_config import cfg
 from oslo_reports import guru_meditation_report as gmr
+from oslo_reports import opts as gmr_opts
 
 from octavia.common import service as octavia_service
-from octavia.controller.queue import consumer
+from octavia.controller.queue.v2 import consumer as consumer_v2
 from octavia import version
 
 CONF = cfg.CONF
@@ -29,10 +30,11 @@ CONF = cfg.CONF
 def main():
     octavia_service.prepare_service(sys.argv)
 
-    gmr.TextGuruMeditation.setup_autorun(version)
+    gmr_opts.set_defaults(CONF)
+    gmr.TextGuruMeditation.setup_autorun(version, conf=CONF)
 
     sm = cotyledon.ServiceManager()
-    sm.add(consumer.ConsumerService, workers=CONF.controller_worker.workers,
-           args=(CONF,))
+    sm.add(consumer_v2.ConsumerService,
+           workers=CONF.controller_worker.workers, args=(CONF,))
     oslo_config_glue.setup(sm, CONF, reload_method="mutate")
     sm.run()
