@@ -24,6 +24,7 @@ from oslo_utils import uuidutils
 from taskflow.conductors.backends import impl_blocking
 from taskflow import engines
 from taskflow import exceptions as taskflow_exc
+from taskflow.jobs.base import Job
 from taskflow.listeners import base
 from taskflow.listeners import logging
 from taskflow.persistence import models
@@ -51,7 +52,45 @@ def retryMaskFilter(record):
 LOG.logger.addFilter(retryMaskFilter)
 
 
-class BaseTaskFlowEngine(object):
+def _details_filter(obj):
+    if isinstance(obj, dict):
+        ret = {}
+        for key in obj:
+            if (key in ('certificate', 'private_key', 'passphrase') and
+                    isinstance(obj[key], str)):
+                ret[key] = '***'
+            elif key == 'intermediates' and isinstance(obj[key], list):
+                ret[key] = ['***'] * len(obj[key])
+            else:
+                ret[key] = _details_filter(obj[key])
+        return ret
+    if isinstance(obj, list):
+        return [_details_filter(e) for e in obj]
+    return obj
+
+
+class FilteredJob(Job):
+    def __str__(self):
+        # Override the default __str__ method from taskflow.job.base.Job,
+        # filter out private information from details
+        cls_name = type(self).__name__
+        details = _details_filter(self.details)
+        return "{}: {} (priority={}, uuid={}, details={})".format(
+            cls_name, self.name, self.priority,
+            self.uuid, details)
+
+
+class JobDetailsFilter(log.logging.Filter):
+    def filter(self, record):
+        # If the first arg is a Job, convert it now to a string with our custom
+        # method
+        if isinstance(record.args[0], Job):
+            arg0 = record.args[0]
+            record.args = (FilteredJob.__str__(arg0),) + record.args[1:]
+        return True
+
+
+class BaseTaskFlowEngine:
     """This is the task flow engine
 
     Use this engine to start/load flows in the
@@ -108,15 +147,16 @@ class DynamicLoggingConductor(impl_blocking.BlockingConductor):
         if (not CONF.task_flow.jobboard_save_logbook and
                 job.state == states.COMPLETE):
             LOG.debug("Job %s is complete. Cleaning up job logbook.", job.name)
-            try:
-                self._persistence.get_connection().destroy_logbook(
-                    job.book.uuid)
-            except taskflow_exc.NotFound:
-                LOG.debug("Logbook for job %s has been already cleaned up",
-                          job.name)
+            if job.book:
+                try:
+                    self._persistence.get_connection().destroy_logbook(
+                        job.book.uuid)
+                except taskflow_exc.NotFound:
+                    LOG.debug("Logbook for job %s has been already cleaned up",
+                              job.name)
 
 
-class RedisDynamicLoggingConductor(DynamicLoggingConductor):
+class ExtendExpiryDynamicLoggingConductor(DynamicLoggingConductor):
 
     def _listeners_from_job(self, job, engine):
         listeners = super()._listeners_from_job(job, engine)
@@ -124,11 +164,16 @@ class RedisDynamicLoggingConductor(DynamicLoggingConductor):
         return listeners
 
 
-class TaskFlowServiceController(object):
+class TaskFlowServiceController:
 
     def __init__(self, driver):
         self.driver = driver
 
+        # Install filter for taskflow executor logger
+        taskflow_logger = log.logging.getLogger(
+            "taskflow.conductors.backends.impl_executor")
+        taskflow_logger.addFilter(JobDetailsFilter())
+
     def run_poster(self, flow_factory, *args, **kwargs):
         with self.driver.persistence_driver.get_persistence() as persistence:
             with self.driver.job_board(persistence) as job_board:
@@ -161,20 +206,29 @@ class TaskFlowServiceController(object):
     def run_conductor(self, name):
         with self.driver.persistence_driver.get_persistence() as persistence:
             with self.driver.job_board(persistence) as board:
-                # Redis do not expire jobs by default, so jobs won't be resumed
-                # with restart of controller. Add expiry for board and use
-                # special listener.
-                if (CONF.task_flow.jobboard_backend_driver ==
-                        'redis_taskflow_driver'):
-                    conductor = RedisDynamicLoggingConductor(
+                # Redis and etcd do not expire jobs by default, so jobs won't
+                # be resumed with restart of controller. Add expiry for board
+                # and use special listener.
+                if (CONF.task_flow.jobboard_backend_driver in (
+                        'etcd_taskflow_driver',
+                        'redis_taskflow_driver')):
+                    conductor = ExtendExpiryDynamicLoggingConductor(
                         name, board, persistence=persistence,
                         engine=CONF.task_flow.engine,
                         engine_options={
                             'max_workers': CONF.task_flow.max_workers
                         })
-                    board.claim = functools.partial(
-                        board.claim,
-                        expiry=CONF.task_flow.jobboard_expiration_time)
+                    if (CONF.task_flow.jobboard_backend_driver ==
+                            'redis_taskflow_driver'):
+                        # Hack for redis only:
+                        # The TTL of the jobs of the Redis Jobboard driver can
+                        # be only overriden by using the 'expiry' parameter of
+                        # the 'claim' function
+                        # For the Etcd driver, the default TTL for all the
+                        # locks can be configured while creating the backend
+                        board.claim = functools.partial(
+                            board.claim,
+                            expiry=CONF.task_flow.jobboard_expiration_time)
                 else:
                     conductor = DynamicLoggingConductor(
                         name, board, persistence=persistence,
