@@ -133,6 +133,12 @@ class UnreadablePKCS12(APIException):
     code = 400
 
 
+class MissingCertSubject(APIException):
+    msg = _('No CN or DNSName(s) found in certificate. The certificate is '
+            'invalid.')
+    code = 400
+
+
 class MisMatchedKey(OctaviaException):
     message = _("Key and x509 certificate do not match")
 
@@ -248,6 +254,11 @@ class ComputePortInUseException(OctaviaException):
     message = _('Compute driver reports port %(port)s is already in use.')
 
 
+class ComputeNoResourcesException(OctaviaException):
+    message = _('The compute service does not have the resources available to '
+                'fulfill the request')
+
+
 class ComputeUnknownException(OctaviaException):
     message = _('Unknown exception from the compute driver: %(exc)s.')
 
@@ -414,3 +425,23 @@ class NetworkServiceError(OctaviaException):
 class InvalidIPAddress(APIException):
     msg = _('The IP Address %(ip_addr)s is invalid.')
     code = 400
+
+
+class AmphoraNetworkConfigException(OctaviaException):
+    message = _('Cannot configure network resource in the amphora: '
+                '%(detail)s')
+
+
+class ListenerNoChildren(APIException):
+    msg = _('Protocol %(protocol)s listeners cannot have child objects.')
+    code = 400
+
+
+class MemberSRIOVDisabled(APIException):
+    msg = _('The load balancer flavor does not allow SR-IOV member ports.')
+    code = 400
+
+
+class VIPAddressConflict(APIException):
+    msg = _('The VIP IP address is already in use: %(msg)s')
+    code = 409
