@@ -14,6 +14,7 @@
 
 import os
 import re
+from typing import Optional
 
 import jinja2
 from octavia_lib.common import constants as lib_consts
@@ -22,6 +23,7 @@ from oslo_utils import versionutils
 from octavia.common.config import cfg
 from octavia.common import constants
 from octavia.common import utils as octavia_utils
+from octavia.db import models
 
 PROTOCOL_MAP = {
     constants.PROTOCOL_TCP: 'tcp',
@@ -58,7 +60,7 @@ CONF = cfg.CONF
 JINJA_ENV = None
 
 
-class JinjaTemplater(object):
+class JinjaTemplater:
 
     def __init__(self,
                  base_amp_path=None,
@@ -85,11 +87,12 @@ class JinjaTemplater(object):
         self.connection_logging = connection_logging
 
     def build_config(self, host_amphora, listeners, tls_certs,
-                     haproxy_versions, socket_path=None):
+                     haproxy_versions, amp_details, socket_path=None):
         """Convert a logical configuration to the HAProxy version
 
         :param host_amphora: The Amphora this configuration is hosted on
         :param listener: The listener configuration
+        :param amp_details: Detail information from the amphora
         :param socket_path: The socket path for Haproxy process
         :return: Rendered configuration
         """
@@ -103,6 +106,7 @@ class JinjaTemplater(object):
         # Is it newer than haproxy 1.5?
         if versionutils.is_compatible("1.6.0", version, same_major=False):
             feature_compatibility[constants.HTTP_REUSE] = True
+            feature_compatibility[constants.SERVER_STATE_FILE] = True
         if versionutils.is_compatible("1.9.0", version, same_major=False):
             feature_compatibility[constants.POOL_ALPN] = True
         if int(haproxy_versions[0]) >= 2:
@@ -114,7 +118,8 @@ class JinjaTemplater(object):
         return self.render_loadbalancer_obj(
             host_amphora, listeners, tls_certs=tls_certs,
             socket_path=socket_path,
-            feature_compatibility=feature_compatibility)
+            feature_compatibility=feature_compatibility,
+            amp_details=amp_details)
 
     def _get_template(self):
         """Returns the specified Jinja configuration template."""
@@ -151,13 +156,15 @@ class JinjaTemplater(object):
 
     def render_loadbalancer_obj(self, host_amphora, listeners,
                                 tls_certs=None, socket_path=None,
-                                feature_compatibility=None):
+                                feature_compatibility=None,
+                                amp_details: Optional[dict] = None):
         """Renders a templated configuration from a load balancer object
 
         :param host_amphora: The Amphora this configuration is hosted on
         :param listener: The listener configuration
         :param tls_certs: Dict of the TLS certificates for the listener
         :param socket_path: The socket path for Haproxy process
+        :param amp_details: Detail information from the amphora
         :return: Rendered configuration
         """
         feature_compatibility = feature_compatibility or {}
@@ -166,35 +173,67 @@ class JinjaTemplater(object):
             listeners[0].load_balancer,
             listeners,
             tls_certs,
-            feature_compatibility,)
+            feature_compatibility)
         if not socket_path:
-            socket_path = '%s/%s.sock' % (self.base_amp_path,
-                                          listeners[0].load_balancer.id)
-        state_file_path = '%s/%s/servers-state' % (
+            socket_path = (f'{self.base_amp_path}/'
+                           f'{listeners[0].load_balancer.id}.sock')
+        state_file_path = '{}/{}/servers-state'.format(
             self.base_amp_path,
-            listeners[0].load_balancer.id)
-        prometheus_listener = False
-        for listener in listeners:
-            if listener.protocol == lib_consts.PROTOCOL_PROMETHEUS:
-                prometheus_listener = True
-                break
+            listeners[0].load_balancer.id) if feature_compatibility.get(
+            constants.SERVER_STATE_FILE) else ''
+        prometheus_listener = any(
+            lsnr.protocol == lib_consts.PROTOCOL_PROMETHEUS for lsnr in
+            listeners)
         require_insecure_fork = feature_compatibility.get(
             constants.INSECURE_FORK)
         enable_prometheus = prometheus_listener and feature_compatibility.get(
             lib_consts.PROTOCOL_PROMETHEUS, False)
+        term_https_listener = any(
+            lsnr.protocol == lib_consts.PROTOCOL_TERMINATED_HTTPS for lsnr in
+            listeners)
+
+        jinja_dict = {
+            'loadbalancer': loadbalancer,
+            'stats_sock': socket_path,
+            'log_http': self.log_http,
+            'log_server': self.log_server,
+            'state_file': state_file_path,
+            'administrative_log_facility':
+                CONF.amphora_agent.administrative_log_facility,
+            'user_log_facility':
+                CONF.amphora_agent.user_log_facility,
+            'connection_logging': self.connection_logging,
+            'enable_prometheus': enable_prometheus,
+            'require_insecure_fork': require_insecure_fork,
+        }
+        try:
+            # Enable cpu-pinning only if the amphora TuneD profile is active
+            if "amphora" in amp_details["active_tuned_profiles"].split():
+                jinja_dict["cpu_count"] = int(amp_details["cpu_count"])
+        except (KeyError, TypeError):
+            pass
+
+        if term_https_listener:
+            try:
+                mem = amp_details["memory"]
+                # Account for 32 KB per established connection for each
+                # pair of HAProxy network sockets. Use 1024 as fallback
+                # because that is what ulimit -n typically returns.
+                max_conn_mem_kb = 32 * loadbalancer.get(
+                    "global_connection_limit", 1024)
+                # LP #2119987: Use 2/5 of the remaining memory for SSL caches
+                ssl_cache_mem_kb = (mem["free"] + mem["buffers"] +
+                                    mem["cached"] - max_conn_mem_kb) * 2 // 5
+                # A cache block uses about 250 bytes of data.
+                # The HAProxy default of ssl_cache (20000) would take up
+                # 5000 KB. We don't want to go below that.
+                if ssl_cache_mem_kb > 5000:
+                    jinja_dict["ssl_cache"] = ssl_cache_mem_kb * 4
+            except (KeyError, TypeError):
+                pass
+
         return self._get_template().render(
-            {'loadbalancer': loadbalancer,
-             'stats_sock': socket_path,
-             'log_http': self.log_http,
-             'log_server': self.log_server,
-             'state_file': state_file_path,
-             'administrative_log_facility':
-                 CONF.amphora_agent.administrative_log_facility,
-             'user_log_facility': CONF.amphora_agent.user_log_facility,
-             'connection_logging': self.connection_logging,
-             'enable_prometheus': enable_prometheus,
-             'require_insecure_fork': require_insecure_fork},
-            constants=constants, lib_consts=lib_consts)
+            jinja_dict, constants=constants, lib_consts=lib_consts)
 
     def _transform_loadbalancer(self, host_amphora, loadbalancer, listeners,
                                 tls_certs, feature_compatibility):
@@ -227,6 +266,8 @@ class JinjaTemplater(object):
         # listeners' connection limits.
         connection_limit_sum = 0
         for listener in listeners:
+            if not listener.enabled:
+                continue
             if listener.protocol in constants.LVS_PROTOCOLS:
                 continue
             if listener.connection_limit and listener.connection_limit > -1:
@@ -260,7 +301,8 @@ class JinjaTemplater(object):
             'vrrp_priority': amphora.vrrp_priority
         }
 
-    def _transform_listener(self, listener, tls_certs, feature_compatibility,
+    def _transform_listener(self, listener: models.Listener, tls_certs,
+                            feature_compatibility,
                             loadbalancer):
         """Transforms a listener into an object that will
 
@@ -299,7 +341,7 @@ class JinjaTemplater(object):
         if listener.tls_certificate_id:
             ret_value['crt_list_filename'] = os.path.join(
                 CONF.haproxy_amphora.base_cert_dir,
-                loadbalancer.id, '{}.pem'.format(listener.id))
+                loadbalancer.id, f'{listener.id}.pem')
 
         if tls_certs is not None:
             if listener.client_ca_tls_certificate_id:
@@ -325,6 +367,13 @@ class JinjaTemplater(object):
                 ret_value['tls_versions'] = listener.tls_versions
             if listener.alpn_protocols is not None:
                 ret_value['alpn_protocols'] = ",".join(listener.alpn_protocols)
+            if listener.hsts_max_age is not None:
+                hsts_directives = f"max-age={listener.hsts_max_age};"
+                if listener.hsts_include_subdomains:
+                    hsts_directives += " includeSubDomains;"
+                if listener.hsts_preload:
+                    hsts_directives += " preload;"
+                ret_value['hsts_directives'] = hsts_directives
 
         pools = []
         pool_gen = (pool for pool in listener.pools if
