@@ -15,6 +15,7 @@ import contextlib
 
 from oslo_config import cfg
 from oslo_log import log
+from oslo_utils import netutils
 from oslo_utils import strutils
 from taskflow.jobs import backends as job_backends
 from taskflow.persistence import backends as persistence_backends
@@ -90,19 +91,16 @@ class RedisTaskFlowDriver(JobboardTaskFlowDriver):
 
     def job_board(self, persistence):
 
-        def _format_server(host, port):
-            if ':' in host:
-                return '[%s]:%d' % (host, port)
-            return '%s:%d' % (host, port)
-
         jobboard_backend_conf = {
             'board': 'redis',
             'host': CONF.task_flow.jobboard_backend_hosts[0],
             'port': CONF.task_flow.jobboard_backend_port,
+            'db': CONF.task_flow.jobboard_redis_backend_db,
             'namespace': CONF.task_flow.jobboard_backend_namespace,
             'sentinel': CONF.task_flow.jobboard_redis_sentinel,
             'sentinel_fallbacks': [
-                _format_server(host, CONF.task_flow.jobboard_backend_port)
+                '%s:%d' % (netutils.escape_ipv6(host),
+                           CONF.task_flow.jobboard_backend_port)
                 for host in CONF.task_flow.jobboard_backend_hosts[1:]
             ]
         }
@@ -131,3 +129,33 @@ class RedisTaskFlowDriver(JobboardTaskFlowDriver):
             CONF.task_flow.jobboard_backend_namespace,
             jobboard_backend_conf,
             persistence=persistence)
+
+
+class EtcdTaskFlowDriver(JobboardTaskFlowDriver):
+
+    def __init__(self, persistence_driver):
+        self.persistence_driver = persistence_driver
+
+    def job_board(self, persistence):
+        jobboard_backend_conf = {
+            'board': 'etcd',
+            'host': CONF.task_flow.jobboard_backend_hosts[0],
+            'port': CONF.task_flow.jobboard_backend_port,
+            'path': CONF.task_flow.jobboard_backend_namespace,
+            'ttl': CONF.task_flow.jobboard_expiration_time,
+        }
+        if CONF.task_flow.jobboard_etcd_ssl_options['use_ssl']:
+            jobboard_backend_conf.update(
+                CONF.task_flow.jobboard_etcd_ssl_options)
+            jobboard_backend_conf.pop('use_ssl')
+            jobboard_backend_conf['protocol'] = 'https'
+        if CONF.task_flow.jobboard_etcd_timeout is not None:
+            jobboard_backend_conf['timeout'] = (
+                CONF.task_flow.jobboard_etcd_timeout)
+        if CONF.task_flow.jobboard_etcd_api_path is not None:
+            jobboard_backend_conf['api_path'] = (
+                CONF.task_flow.jobboard_etcd_api_path)
+
+        return job_backends.backend(CONF.task_flow.jobboard_backend_namespace,
+                                    jobboard_backend_conf,
+                                    persistence=persistence)
