@@ -15,7 +15,6 @@
 
 import time
 
-from cryptography import fernet
 from oslo_config import cfg
 from oslo_log import log as logging
 from stevedore import driver as stevedore_driver
@@ -107,13 +106,9 @@ class ComputeCreate(BaseComputeTask):
             amp_image_tag = CONF.controller_worker.amp_image_tag
 
         if availability_zone:
-            amp_availability_zone = availability_zone.get(
-                constants.COMPUTE_ZONE)
             amp_network = availability_zone.get(constants.MANAGEMENT_NETWORK)
             if amp_network:
                 network_ids = [amp_network]
-        else:
-            amp_availability_zone = None
         try:
             if CONF.haproxy_amphora.build_rate_limit != -1:
                 self.rate_limit.add_to_build_request_queue(
@@ -146,7 +141,7 @@ class ComputeCreate(BaseComputeTask):
                 config_drive_files=config_drive_files,
                 user_data=user_data,
                 server_group_id=server_group_id,
-                availability_zone=amp_availability_zone)
+                availability_zone=availability_zone)
 
             LOG.info("Server created with id: %s for amphora id: %s",
                      compute_id, amphora_id)
@@ -190,8 +185,7 @@ class CertComputeCreate(ComputeCreate):
                   encoding='utf-8') as client_ca:
             ca = client_ca.read()
 
-        key = utils.get_compatible_server_certs_key_passphrase()
-        fer = fernet.Fernet(key)
+        fer = utils.get_server_certs_key_passphrases_fernet()
         config_drive_files = {
             '/etc/octavia/certs/server.pem': fer.decrypt(
                 server_pem.encode("utf-8")).decode("utf-8"),
