@@ -118,25 +118,23 @@ class TestAvailabilityZones(base.BaseAPITest):
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
         project_id = uuidutils.generate_uuid()
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
-                               project_id):
-            override_credentials = {
-                'service_user_id': None,
-                'user_domain_id': None,
-                'is_admin_project': True,
-                'service_project_domain_id': None,
-                'service_project_id': None,
-                'roles': ['load-balancer_member'],
-                'user_id': None,
-                'is_admin': True,
-                'service_user_domain_id': None,
-                'project_domain_id': None,
-                'service_roles': [],
-                'project_id': project_id}
-            with mock.patch(
-                    "oslo_context.context.RequestContext.to_policy_values",
-                    return_value=override_credentials):
-                response = self.post(self.AZS_PATH, body)
+        override_credentials = {
+            'service_user_id': None,
+            'user_domain_id': None,
+            'is_admin_project': True,
+            'service_project_domain_id': None,
+            'service_project_id': None,
+            'roles': ['load-balancer_member'],
+            'user_id': None,
+            'is_admin': True,
+            'service_user_domain_id': None,
+            'project_domain_id': None,
+            'service_roles': [],
+            'project_id': project_id}
+        with mock.patch(
+                "oslo_context.context.RequestContext.to_policy_values",
+                return_value=override_credentials):
+            response = self.post(self.AZS_PATH, body)
         api_az = response.json.get(self.root_tag)
         self.conf.config(group='api_settings', auth_strategy=auth_strategy)
         self._assert_request_matches_response(az_json, api_az)
@@ -185,15 +183,15 @@ class TestAvailabilityZones(base.BaseAPITest):
         self.assertEqual(az.get('name'), response.get('name'))
         self.assertEqual(self.azp.get('id'),
                          response.get('availability_zone_profile_id'))
-        self.assertIn(u'availability_zone_profile_id', response)
-        self.assertNotIn(u'description', response)
-        self.assertNotIn(u'enabled', response)
+        self.assertIn('availability_zone_profile_id', response)
+        self.assertNotIn('description', response)
+        self.assertNotIn('enabled', response)
 
     def test_get_one_deleted_name(self):
         response = self.get(
             self.AZ_PATH.format(az_name=constants.NIL_UUID), status=404)
         self.assertEqual(
-            'Availability Zone {} not found.'.format(constants.NIL_UUID),
+            f'Availability Zone {constants.NIL_UUID} not found.',
             response.json.get('faultstring'))
 
     def test_get_authorized(self):
@@ -204,15 +202,17 @@ class TestAvailabilityZones(base.BaseAPITest):
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
         project_id = uuidutils.generate_uuid()
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
-                               project_id):
+        test_context = octavia.common.context.RequestContext(
+            project_id=project_id)
+        with mock.patch('oslo_context.context.RequestContext.from_environ',
+                        return_value=test_context):
             override_credentials = {
                 'service_user_id': None,
                 'user_domain_id': None,
                 'is_admin_project': True,
                 'service_project_domain_id': None,
                 'service_project_id': None,
-                'roles': ['load-balancer_member'],
+                'roles': ['load-balancer_member', 'member'],
                 'user_id': None,
                 'is_admin': False,
                 'service_user_domain_id': None,
@@ -247,15 +247,15 @@ class TestAvailabilityZones(base.BaseAPITest):
         self.create_availability_zone(
             'name1', 'description', self.azp.get('id'), True)
         ref_az_1 = {
-            u'description': u'description', u'enabled': True,
-            u'availability_zone_profile_id': self.azp.get('id'),
-            u'name': u'name1'}
+            'description': 'description', 'enabled': True,
+            'availability_zone_profile_id': self.azp.get('id'),
+            'name': 'name1'}
         self.create_availability_zone(
             'name2', 'description', self.azp.get('id'), True)
         ref_az_2 = {
-            u'description': u'description', u'enabled': True,
-            u'availability_zone_profile_id': self.azp.get('id'),
-            u'name': u'name2'}
+            'description': 'description', 'enabled': True,
+            'availability_zone_profile_id': self.azp.get('id'),
+            'name': 'name2'}
         response = self.get(self.AZS_PATH)
         api_list = response.json.get(self.root_tag_list)
         self.assertEqual(2, len(api_list))
@@ -272,10 +272,10 @@ class TestAvailabilityZones(base.BaseAPITest):
         api_list = response.json.get(self.root_tag_list)
         self.assertEqual(2, len(api_list))
         for az in api_list:
-            self.assertIn(u'name', az)
-            self.assertNotIn(u'availability_zone_profile_id', az)
-            self.assertNotIn(u'description', az)
-            self.assertNotIn(u'enabled', az)
+            self.assertIn('name', az)
+            self.assertNotIn('availability_zone_profile_id', az)
+            self.assertNotIn('description', az)
+            self.assertNotIn('enabled', az)
 
     def test_get_all_authorized(self):
         self.create_availability_zone(
@@ -288,25 +288,23 @@ class TestAvailabilityZones(base.BaseAPITest):
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
         project_id = uuidutils.generate_uuid()
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
-                               project_id):
-            override_credentials = {
-                'service_user_id': None,
-                'user_domain_id': None,
-                'is_admin_project': True,
-                'service_project_domain_id': None,
-                'service_project_id': None,
-                'roles': ['load-balancer_member'],
-                'user_id': None,
-                'is_admin': False,
-                'service_user_domain_id': None,
-                'project_domain_id': None,
-                'service_roles': [],
-                'project_id': project_id}
-            with mock.patch(
-                    "oslo_context.context.RequestContext.to_policy_values",
-                    return_value=override_credentials):
-                api_list = response.json.get(self.root_tag_list)
+        override_credentials = {
+            'service_user_id': None,
+            'user_domain_id': None,
+            'is_admin_project': True,
+            'service_project_domain_id': None,
+            'service_project_id': None,
+            'roles': ['load-balancer_member'],
+            'user_id': None,
+            'is_admin': False,
+            'service_user_domain_id': None,
+            'project_domain_id': None,
+            'service_roles': [],
+            'project_id': project_id}
+        with mock.patch(
+                "oslo_context.context.RequestContext.to_policy_values",
+                return_value=override_credentials):
+            api_list = response.json.get(self.root_tag_list)
         self.conf.config(group='api_settings', auth_strategy=auth_strategy)
         self.assertEqual(2, len(api_list))
 
@@ -352,7 +350,7 @@ class TestAvailabilityZones(base.BaseAPITest):
             self.AZ_PATH.format(az_name=constants.NIL_UUID), body,
             status=404)
         self.assertEqual(
-            'Availability Zone {} not found.'.format(constants.NIL_UUID),
+            f'Availability Zone {constants.NIL_UUID} not found.',
             response.json.get('faultstring'))
 
     def test_update_none(self):
@@ -412,26 +410,24 @@ class TestAvailabilityZones(base.BaseAPITest):
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
         project_id = uuidutils.generate_uuid()
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
-                               project_id):
-            override_credentials = {
-                'service_user_id': None,
-                'user_domain_id': None,
-                'is_admin_project': True,
-                'service_project_domain_id': None,
-                'service_project_id': None,
-                'roles': ['load-balancer_member'],
-                'user_id': None,
-                'is_admin': True,
-                'service_user_domain_id': None,
-                'project_domain_id': None,
-                'service_roles': [],
-                'project_id': project_id}
-            with mock.patch(
-                    "oslo_context.context.RequestContext.to_policy_values",
-                    return_value=override_credentials):
-                self.put(self.AZ_PATH.format(az_name=availability_zone_name),
-                         body)
+        override_credentials = {
+            'service_user_id': None,
+            'user_domain_id': None,
+            'is_admin_project': True,
+            'service_project_domain_id': None,
+            'service_project_id': None,
+            'roles': ['load-balancer_member'],
+            'user_id': None,
+            'is_admin': True,
+            'service_user_domain_id': None,
+            'project_domain_id': None,
+            'service_roles': [],
+            'project_id': project_id}
+        with mock.patch(
+                "oslo_context.context.RequestContext.to_policy_values",
+                return_value=override_credentials):
+            self.put(self.AZ_PATH.format(az_name=availability_zone_name),
+                     body)
         self.conf.config(group='api_settings', auth_strategy=auth_strategy)
 
         updated_az = self.get(self.AZ_PATH.format(
@@ -488,7 +484,7 @@ class TestAvailabilityZones(base.BaseAPITest):
         self.delete(self.AZ_PATH.format(az_name=az.get('name')))
         response = self.get(self.AZ_PATH.format(az_name=az.get('name')),
                             status=404)
-        err_msg = "Availability Zone %s not found." % az.get('name')
+        err_msg = f"Availability Zone {az.get('name')} not found."
         self.assertEqual(err_msg, response.json.get('faultstring'))
 
     def test_delete_nonexistent_name(self):
@@ -501,7 +497,7 @@ class TestAvailabilityZones(base.BaseAPITest):
         response = self.delete(
             self.AZ_PATH.format(az_name=constants.NIL_UUID), status=404)
         self.assertEqual(
-            'Availability Zone {} not found.'.format(constants.NIL_UUID),
+            f'Availability Zone {constants.NIL_UUID} not found.',
             response.json.get('faultstring'))
 
     def test_delete_authorized(self):
@@ -511,30 +507,28 @@ class TestAvailabilityZones(base.BaseAPITest):
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
         project_id = uuidutils.generate_uuid()
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
-                               project_id):
-            override_credentials = {
-                'service_user_id': None,
-                'user_domain_id': None,
-                'is_admin_project': True,
-                'service_project_domain_id': None,
-                'service_project_id': None,
-                'roles': ['load-balancer_member'],
-                'user_id': None,
-                'is_admin': True,
-                'service_user_domain_id': None,
-                'project_domain_id': None,
-                'service_roles': [],
-                'project_id': project_id}
-            with mock.patch(
-                    "oslo_context.context.RequestContext.to_policy_values",
-                    return_value=override_credentials):
-                self.delete(
-                    self.AZ_PATH.format(az_name=az.get('name')))
+        override_credentials = {
+            'service_user_id': None,
+            'user_domain_id': None,
+            'is_admin_project': True,
+            'service_project_domain_id': None,
+            'service_project_id': None,
+            'roles': ['load-balancer_member'],
+            'user_id': None,
+            'is_admin': True,
+            'service_user_domain_id': None,
+            'project_domain_id': None,
+            'service_roles': [],
+            'project_id': project_id}
+        with mock.patch(
+                "oslo_context.context.RequestContext.to_policy_values",
+                return_value=override_credentials):
+            self.delete(
+                self.AZ_PATH.format(az_name=az.get('name')))
         self.conf.config(group='api_settings', auth_strategy=auth_strategy)
         response = self.get(self.AZ_PATH.format(az_name=az.get('name')),
                             status=404)
-        err_msg = "Availability Zone %s not found." % az.get('name')
+        err_msg = f"Availability Zone {az.get('name')} not found."
         self.assertEqual(err_msg, response.json.get('faultstring'))
 
     def test_delete_not_authorized(self):
