@@ -14,6 +14,7 @@
 
 import datetime
 
+from oslo_utils import timeutils
 from oslo_utils import uuidutils
 
 from octavia.common import constants
@@ -24,7 +25,7 @@ from octavia.tests.functional.db import base
 from sqlalchemy.orm import collections
 
 
-class ModelTestMixin(object):
+class ModelTestMixin:
 
     FAKE_IP = '10.0.0.1'
     FAKE_UUID_1 = uuidutils.generate_uuid()
@@ -32,9 +33,9 @@ class ModelTestMixin(object):
     FAKE_AZ = 'zone1'
 
     def _insert(self, session, model_cls, model_kwargs):
-        with session.begin():
-            model = model_cls(**model_kwargs)
-            session.add(model)
+        model = model_cls(**model_kwargs)
+        session.add(model)
+        session.commit()
         return model
 
     def create_flavor_profile(self, session, **overrides):
@@ -157,7 +158,7 @@ class ModelTestMixin(object):
                   'vrrp_port_id': self.FAKE_UUID_1,
                   'ha_port_id': self.FAKE_UUID_2,
                   'lb_network_ip': self.FAKE_IP,
-                  'cert_expiration': datetime.datetime.utcnow(),
+                  'cert_expiration': timeutils.utcnow(),
                   'cert_busy': False,
                   'cached_zone': self.FAKE_AZ}
         kwargs.update(overrides)
@@ -230,9 +231,8 @@ class PoolModelTest(base.OctaviaDBTestBase, ModelTestMixin):
     def test_delete(self):
         pool = self.create_pool(self.session)
         id = pool.id
-        with self.session.begin():
-            self.session.delete(pool)
-            self.session.flush()
+        self.session.delete(pool)
+        self.session.commit()
         new_pool = self.session.query(
             models.Pool).filter_by(id=id).first()
         self.assertIsNone(new_pool)
@@ -290,7 +290,8 @@ class MemberModelTest(base.OctaviaDBTestBase, ModelTestMixin):
                          f"project_id={member.project_id!r}, "
                          f"provisioning_status='ACTIVE', "
                          f"ip_address='10.0.0.1', protocol_port=80, "
-                         f"operating_status='ONLINE', weight=None)",
+                         f"operating_status='ONLINE', weight=None, "
+                         f"vnic_type=None)",
                          str(member))
 
         self.assertIsNotNone(member.created_at)
@@ -302,6 +303,7 @@ class MemberModelTest(base.OctaviaDBTestBase, ModelTestMixin):
 
         member_id = member.id
         member.enabled = False
+        self.session.commit()
 
         new_member = self.session.query(
             models.Member).filter_by(id=member_id).first()
@@ -311,9 +313,11 @@ class MemberModelTest(base.OctaviaDBTestBase, ModelTestMixin):
     def test_delete(self):
         member = self.create_member(self.session, self.pool.id)
         member_id = member.id
-        with self.session.begin():
-            self.session.delete(member)
-            self.session.flush()
+        self.session.commit()
+
+        self.session.delete(member)
+        self.session.commit()
+
         new_member = self.session.query(
             models.Member).filter_by(id=member_id).first()
         self.assertIsNone(new_member)
@@ -424,9 +428,8 @@ class ListenerModelTest(base.OctaviaDBTestBase, ModelTestMixin):
     def test_delete(self):
         listener = self.create_listener(self.session)
         listener_id = listener.id
-        with self.session.begin():
-            self.session.delete(listener)
-            self.session.flush()
+        self.session.delete(listener)
+        self.session.commit()
         new_listener = self.session.query(
             models.Listener).filter_by(id=listener_id).first()
         self.assertIsNone(new_listener)
@@ -578,9 +581,8 @@ class LoadBalancerModelTest(base.OctaviaDBTestBase, ModelTestMixin):
     def test_delete(self):
         load_balancer = self.create_load_balancer(self.session)
         lb_id = load_balancer.id
-        with self.session.begin():
-            self.session.delete(load_balancer)
-            self.session.flush()
+        self.session.delete(load_balancer)
+        self.session.commit()
         new_load_balancer = self.session.query(
             models.LoadBalancer).filter_by(id=lb_id).first()
         self.assertIsNone(new_load_balancer)
@@ -622,7 +624,8 @@ class VipModelTest(base.OctaviaDBTestBase, ModelTestMixin):
         self.assertEqual(f"Vip(ip_address=None, "
                          f"load_balancer_id={obj.load_balancer_id!r}, "
                          f"network_id=None, octavia_owned=None, port_id=None, "
-                         f"qos_policy_id=None, subnet_id=None)", str(obj))
+                         f"qos_policy_id=None, subnet_id=None, "
+                         f"vnic_type=None)", str(obj))
 
     def test_update(self):
         vip = self.create_vip(self.session, self.load_balancer.id)
@@ -745,7 +748,7 @@ class AmphoraHealthModelTest(base.OctaviaDBTestBase, ModelTestMixin):
         new_amphora_health = self.session.query(
             models.AmphoraHealth).filter_by(
             amphora_id=amphora_health.amphora_id).first()
-        self.assertEqual(newdate, new_amphora_health.last_update.date())
+        self.assertEqual(newdate, new_amphora_health.last_update)
 
     def test_delete(self):
         amphora_health = self.create_amphora_health(
@@ -787,9 +790,8 @@ class L7PolicyModelTest(base.OctaviaDBTestBase, ModelTestMixin):
     def test_delete(self):
         l7policy = self.create_l7policy(self.session, self.listener.id)
         l7policy_id = l7policy.id
-        with self.session.begin():
-            self.session.delete(l7policy)
-            self.session.flush()
+        self.session.delete(l7policy)
+        self.session.commit()
         new_l7policy = self.session.query(
             models.L7Policy).filter_by(id=l7policy_id).first()
         self.assertIsNone(new_l7policy)
@@ -908,9 +910,8 @@ class L7RuleModelTest(base.OctaviaDBTestBase, ModelTestMixin):
     def test_delete(self):
         l7rule = self.create_l7rule(self.session, self.l7policy.id)
         l7rule_id = l7rule.id
-        with self.session.begin():
-            self.session.delete(l7rule)
-            self.session.flush()
+        self.session.delete(l7rule)
+        self.session.commit()
         new_l7rule = self.session.query(
             models.L7Rule).filter_by(id=l7rule_id).first()
         self.assertIsNone(new_l7rule)
@@ -1050,6 +1051,7 @@ class TestDataModelConversionTest(base.OctaviaDBTestBase, ModelTestMixin):
         # Generate equivalent graphs starting arbitrarily from different
         # nodes within it; Make sure the resulting graphs all contain the
         # same number of nodes.
+        # check the default value for recursion_depth=None
         lb_dm = self.session.query(models.LoadBalancer).filter_by(
             id=self.lb.id).first().to_data_model()
         lb_graph_count = self.count_graph_nodes(lb_dm)
@@ -1064,6 +1066,82 @@ class TestDataModelConversionTest(base.OctaviaDBTestBase, ModelTestMixin):
         self.assertEqual(lb_graph_count, p_graph_count)
         self.assertEqual(lb_graph_count, mem_graph_count)
 
+    def _get_dms_for_recursion_depth(self, recursion_depth):
+        lb_dm = self.session.query(models.LoadBalancer).filter_by(
+            id=self.lb.id).first().to_data_model(
+            recursion_depth=recursion_depth)
+        p_dm = self.session.query(models.Pool).filter_by(
+            id=self.pool.id).first().to_data_model(
+            recursion_depth=recursion_depth)
+        mem_dm = self.session.query(models.Member).filter_by(
+            id=self.member.id).first().to_data_model(
+            recursion_depth=recursion_depth)
+        return lb_dm, p_dm, mem_dm
+
+    def _get_nodes_count_for_dms(self, lb_dm, p_dm, mem_dm):
+        return (
+            self.count_graph_nodes(lb_dm),
+            self.count_graph_nodes(p_dm),
+            self.count_graph_nodes(mem_dm),
+        )
+
+    def test_graph_completeness_with_recursion_depth_equal_zero(self):
+        lb_dm, p_dm, mem_dm = self._get_dms_for_recursion_depth(
+            recursion_depth=0
+        )
+        lb_graph_count, p_graph_count, mem_graph_count = (
+            self._get_nodes_count_for_dms(lb_dm, p_dm, mem_dm)
+        )
+        self.assertNotEqual(0, lb_graph_count)
+        # recursion_depth equal to 0 means, that only current node will be
+        # handled. there is no recursion
+        self.assertEqual(1, lb_graph_count)
+        self.assertEqual(1, p_graph_count)
+        self.assertEqual(1, mem_graph_count)
+
+    def test_graph_completeness_with_recursion_depth_equal_one(self):
+        lb_dm, p_dm, mem_dm = self._get_dms_for_recursion_depth(
+            recursion_depth=1
+        )
+        lb_graph_count, p_graph_count, mem_graph_count = (
+            self._get_nodes_count_for_dms(lb_dm, p_dm, mem_dm)
+        )
+        self.assertNotEqual(0, lb_graph_count)
+        self.assertNotEqual(1, lb_graph_count)
+        self.assertNotEqual(1, p_graph_count)
+        self.assertNotEqual(1, mem_graph_count)
+        # the nodes count is different for each node type
+        # due to different number of related nodes
+        self.assertEqual(5, lb_graph_count)
+        self.assertEqual(7, p_graph_count)
+        self.assertEqual(2, mem_graph_count)
+
+    def test_graph_completeness_with_recursion_depth_huge(self):
+        lb_dm, p_dm, mem_dm = self._get_dms_for_recursion_depth(
+            recursion_depth=10
+        )
+        lb_graph_count, p_graph_count, mem_graph_count = (
+            self._get_nodes_count_for_dms(lb_dm, p_dm, mem_dm)
+        )
+        # recursion_depth=None is default value, so it's equal to run without
+        # limit on recursion
+        lb_dm_none, p_dm_none, mem_dm_none = self._get_dms_for_recursion_depth(
+            recursion_depth=None
+        )
+        lb_graph_count_none, p_graph_count_none, mem_graph_count_none = (
+            self._get_nodes_count_for_dms(lb_dm_none, p_dm_none, mem_dm_none)
+        )
+        self.assertNotEqual(0, lb_graph_count)
+        self.assertNotEqual(1, lb_graph_count)
+        self.assertEqual(lb_graph_count, p_graph_count)
+        self.assertEqual(lb_graph_count, mem_graph_count)
+
+        # huge recursion_depth is enough to iterate through all nodes in graph
+        self.assertEqual(
+            (lb_graph_count, p_graph_count, mem_graph_count),
+            (lb_graph_count_none, p_graph_count_none, mem_graph_count_none)
+        )
+
     def test_data_model_graph_traversal(self):
         lb_dm = self.session.query(models.LoadBalancer).filter_by(
             id=self.lb.id).first().to_data_model()
@@ -1086,6 +1164,51 @@ class TestDataModelConversionTest(base.OctaviaDBTestBase, ModelTestMixin):
                    load_balancer.pools[0].members[0].pool.load_balancer.id)
         self.assertEqual(lb_dm.id, m_lb_id)
 
+    def test_data_model_graph_traversal_with_recursion_depth_zero(self):
+        lb_dm, p_dm, mem_dm = self._get_dms_for_recursion_depth(
+            recursion_depth=0
+        )
+        # Traverse is not possible, because resources are not handled
+        # It happens, because there is no recursion
+        self.assertEqual([], lb_dm.listeners)
+        self.assertEqual([], lb_dm.pools)
+        self.assertIsNone(lb_dm.vip)
+        self.assertEqual([], lb_dm.amphorae)
+        # not inner objects for Pool
+        self.assertEqual([], p_dm.listeners)
+        self.assertIsNone(p_dm.load_balancer)
+        self.assertIsNone(p_dm.session_persistence)
+        self.assertIsNone(p_dm.health_monitor)
+        self.assertEqual([], p_dm.members)
+        self.assertEqual([], p_dm.l7policies)
+        # not inner objects for Member
+        self.assertIsNone(mem_dm.pool)
+
+    def test_data_model_graph_traversal_with_recursion_depth_one(self):
+        lb_dm, p_dm, mem_dm = self._get_dms_for_recursion_depth(
+            recursion_depth=1
+        )
+        # one hop resources are available for LB
+        self.assertEqual(1, len(lb_dm.listeners))
+        self.assertEqual(1, len(lb_dm.pools))
+        self.assertIsNotNone(lb_dm.vip)
+        self.assertEqual(1, len(lb_dm.amphorae))
+        # second hop resources are not available for LB
+        self.assertEqual([], lb_dm.pools[0].listeners)
+        # one hop resources are available for Pool
+        self.assertEqual(1, len(p_dm.listeners))
+        self.assertIsNotNone(p_dm.load_balancer)
+        self.assertIsNotNone(p_dm.session_persistence)
+        self.assertIsNotNone(p_dm.health_monitor)
+        self.assertEqual(1, len(p_dm.members))
+        self.assertEqual(1, len(p_dm.l7policies))
+        # second hop resources are not available for Pool
+        self.assertEqual([], p_dm.load_balancer.listeners)
+        # one hop resources are available for Member
+        self.assertIsNotNone(mem_dm.pool)
+        # second hop resources are not available for Member
+        self.assertEqual([], mem_dm.pool.listeners)
+
     def test_update_data_model_listener_default_pool_id(self):
         lb_dm = self.create_load_balancer(
             self.session, id=uuidutils.generate_uuid()).to_data_model()
@@ -1825,10 +1948,11 @@ class FlavorModelTest(base.OctaviaDBTestBase, ModelTestMixin):
         flavor = self.create_flavor(self.session, self.profile.id)
         self.assertIsNotNone(flavor.id)
         id = flavor.id
+        self.session.commit()
+
+        self.session.delete(flavor)
+        self.session.commit()
 
-        with self.session.begin():
-            self.session.delete(flavor)
-            self.session.flush()
         new_flavor = self.session.query(
             models.Flavor).filter_by(id=id).first()
         self.assertIsNone(new_flavor)
@@ -1847,10 +1971,10 @@ class FlavorProfileModelTest(base.OctaviaDBTestBase, ModelTestMixin):
         fp = self.create_flavor_profile(self.session)
         self.assertIsNotNone(fp.id)
         id = fp.id
+        self.session.commit()
 
-        with self.session.begin():
-            self.session.delete(fp)
-            self.session.flush()
+        self.session.delete(fp)
+        self.session.commit()
         new_fp = self.session.query(
             models.FlavorProfile).filter_by(id=id).first()
         self.assertIsNone(new_fp)
