@@ -15,6 +15,7 @@
 import errno
 import os
 import socket
+import subprocess
 from unittest import mock
 
 import pyroute2
@@ -36,7 +37,7 @@ class TestInterface(base.TestCase):
 
         ifaces = ('eth0', 'eth7', 'eth8')
         mock_listdir.return_value = [
-            "{}.json".format(iface)
+            f"{iface}.json"
             for iface in ifaces
         ]
         mock_listdir.return_value.extend(["invalidfile"])
@@ -47,7 +48,7 @@ class TestInterface(base.TestCase):
 
         for iface in ifaces:
             f = os.path.join(consts.AMP_NET_DIR_TEMPLATE,
-                             "{}.json".format(iface))
+                             f"{iface}.json")
             self.assertIn(f, config_file_list)
 
         # unsupported file
@@ -74,6 +75,7 @@ class TestInterface(base.TestCase):
                    '],\n'
                    '"mtu": 1450,\n'
                    '"name": "eth1",\n'
+                   '"if_type": "mytype",\n'
                    '"routes": [\n'
                    '{"dst": "0.0.0.0/0",\n'
                    '"gateway": "10.0.0.1"},\n'
@@ -107,6 +109,7 @@ class TestInterface(base.TestCase):
 
         expected_dict = {
             consts.NAME: "eth1",
+            consts.IF_TYPE: "mytype",
             consts.MTU: 1450,
             consts.ADDRESSES: [{
                 consts.ADDRESS: "10.0.0.2",
@@ -271,11 +274,10 @@ class TestInterface(base.TestCase):
         mock_check_output.assert_called_once_with(
             ["/sbin/dhclient",
              "-lf",
-             "/var/lib/dhclient/dhclient-{}.leases".format(
-                 iface),
+             f"/var/lib/dhclient/dhclient-{iface}.leases",
              "-pf",
-             "/run/dhclient-{}.pid".format(iface),
-             iface], stderr=-2)
+             f"/run/dhclient-{iface}.pid",
+             iface], stderr=subprocess.STDOUT)
 
     @mock.patch('subprocess.check_output')
     def test__dhclient_down(self, mock_check_output):
@@ -288,11 +290,10 @@ class TestInterface(base.TestCase):
             ["/sbin/dhclient",
              "-r",
              "-lf",
-             "/var/lib/dhclient/dhclient-{}.leases".format(
-                 iface),
+             f"/var/lib/dhclient/dhclient-{iface}.leases",
              "-pf",
-             "/run/dhclient-{}.pid".format(iface),
-             iface], stderr=-2)
+             f"/run/dhclient-{iface}.pid",
+             iface], stderr=subprocess.STDOUT)
 
     @mock.patch('subprocess.check_output')
     def test__ipv6auto_up(self, mock_check_output):
@@ -303,9 +304,11 @@ class TestInterface(base.TestCase):
 
         mock_check_output.assert_has_calls([
             mock.call(["/sbin/sysctl", "-w",
-                       "net.ipv6.conf.iface2.accept_ra=2"], stderr=-2),
+                       "net.ipv6.conf.iface2.accept_ra=2"],
+                      stderr=subprocess.STDOUT),
             mock.call(["/sbin/sysctl", "-w",
-                       "net.ipv6.conf.iface2.autoconf=1"], stderr=-2)])
+                       "net.ipv6.conf.iface2.autoconf=1"],
+                      stderr=subprocess.STDOUT)])
 
     @mock.patch('subprocess.check_output')
     def test__ipv6auto_down(self, mock_check_output):
@@ -316,21 +319,24 @@ class TestInterface(base.TestCase):
 
         mock_check_output.assert_has_calls([
             mock.call(["/sbin/sysctl", "-w",
-                       "net.ipv6.conf.iface2.accept_ra=0"], stderr=-2),
+                       "net.ipv6.conf.iface2.accept_ra=0"],
+                      stderr=subprocess.STDOUT),
             mock.call(["/sbin/sysctl", "-w",
-                       "net.ipv6.conf.iface2.autoconf=0"], stderr=-2)])
+                       "net.ipv6.conf.iface2.autoconf=0"],
+                      stderr=subprocess.STDOUT)])
 
-    @mock.patch('pyroute2.IPRoute.rule')
-    @mock.patch('pyroute2.IPRoute.route')
-    @mock.patch('pyroute2.IPRoute.addr')
-    @mock.patch('pyroute2.IPRoute.link')
-    @mock.patch('pyroute2.IPRoute.get_links')
-    @mock.patch('pyroute2.IPRoute.link_lookup')
+    @mock.patch('pyroute2.IPRoute.rule', create=True)
+    @mock.patch('pyroute2.IPRoute.route', create=True)
+    @mock.patch('pyroute2.IPRoute.addr', create=True)
+    @mock.patch('pyroute2.IPRoute.link', create=True)
+    @mock.patch('pyroute2.IPRoute.get_links', create=True)
+    @mock.patch('pyroute2.IPRoute.link_lookup', create=True)
     @mock.patch('subprocess.check_output')
     def test_up(self, mock_check_output, mock_link_lookup, mock_get_links,
                 mock_link, mock_addr, mock_route, mock_rule):
         iface = interface_file.InterfaceFile(
             name="eth1",
+            if_type="vip",
             mtu=1450,
             addresses=[{
                 consts.ADDRESS: '1.2.3.4',
@@ -445,15 +451,222 @@ class TestInterface(base.TestCase):
             mock.call(["post-up", "eth1"])
         ])
 
-    @mock.patch('pyroute2.IPRoute.rule')
-    @mock.patch('pyroute2.IPRoute.route')
-    @mock.patch('pyroute2.IPRoute.addr')
-    @mock.patch('pyroute2.IPRoute.link')
-    @mock.patch('pyroute2.IPRoute.get_links')
-    @mock.patch('pyroute2.IPRoute.get_rules')
-    @mock.patch('pyroute2.IPRoute.get_routes')
-    @mock.patch('pyroute2.IPRoute.get_addr')
-    @mock.patch('pyroute2.IPRoute.link_lookup')
+    @mock.patch('octavia.amphorae.backends.utils.network_namespace.'
+                'NetworkNamespace')
+    @mock.patch('octavia.amphorae.backends.utils.nftable_utils.'
+                'write_nftable_rules_file')
+    @mock.patch('pyroute2.IPRoute.rule', create=True)
+    @mock.patch('pyroute2.IPRoute.route', create=True)
+    @mock.patch('pyroute2.IPRoute.addr', create=True)
+    @mock.patch('pyroute2.IPRoute.link', create=True)
+    @mock.patch('pyroute2.IPRoute.get_links', create=True)
+    @mock.patch('pyroute2.IPRoute.link_lookup', create=True)
+    @mock.patch('subprocess.check_output')
+    def test_up_sriov(self, mock_check_output, mock_link_lookup,
+                      mock_get_links, mock_link, mock_addr, mock_route,
+                      mock_rule, mock_nftable, mock_netns):
+        iface = interface_file.InterfaceFile(
+            name="fake-eth1",
+            if_type="vip",
+            mtu=1450,
+            addresses=[{
+                consts.ADDRESS: '192.0.2.4',
+                consts.PREFIXLEN: 24
+            }, {
+                consts.ADDRESS: '198.51.100.4',
+                consts.PREFIXLEN: 16
+            }, {
+                consts.ADDRESS: '2001:db8::3',
+                consts.PREFIXLEN: 64
+            }],
+            routes=[{
+                consts.DST: '203.0.113.0/24',
+                consts.GATEWAY: '192.0.2.1',
+                consts.TABLE: 10,
+                consts.ONLINK: True
+            }, {
+                consts.DST: '198.51.100.0/24',
+                consts.GATEWAY: '192.0.2.2',
+                consts.PREFSRC: '192.0.2.4',
+                consts.SCOPE: 'link'
+            }, {
+                consts.DST: '2001:db8:2::1/128',
+                consts.GATEWAY: '2001:db8::1'
+            }],
+            rules=[{
+                consts.SRC: '203.0.113.1',
+                consts.SRC_LEN: 32,
+                consts.TABLE: 20,
+            }, {
+                consts.SRC: '2001:db8::1',
+                consts.SRC_LEN: 128,
+                consts.TABLE: 40,
+            }],
+            scripts={
+                consts.IFACE_UP: [{
+                    consts.COMMAND: "post-up fake-eth1"
+                }],
+                consts.IFACE_DOWN: [{
+                    consts.COMMAND: "post-down fake-eth1"
+                }],
+            },
+            is_sriov=True)
+
+        idx = mock.MagicMock()
+        mock_link_lookup.return_value = [idx]
+
+        mock_get_links.return_value = [{
+            consts.STATE: consts.IFACE_DOWN
+        }]
+
+        controller = interface.InterfaceController()
+        controller.up(iface)
+
+        mock_link.assert_called_once_with(
+            controller.SET,
+            index=idx,
+            state=consts.IFACE_UP,
+            mtu=1450)
+
+        mock_addr.assert_has_calls([
+            mock.call(controller.ADD,
+                      index=idx,
+                      address='192.0.2.4',
+                      prefixlen=24,
+                      family=socket.AF_INET),
+            mock.call(controller.ADD,
+                      index=idx,
+                      address='198.51.100.4',
+                      prefixlen=16,
+                      family=socket.AF_INET),
+            mock.call(controller.ADD,
+                      index=idx,
+                      address='2001:db8::3',
+                      prefixlen=64,
+                      family=socket.AF_INET6)
+        ])
+
+        mock_route.assert_has_calls([
+            mock.call(controller.ADD,
+                      oif=idx,
+                      dst='203.0.113.0/24',
+                      gateway='192.0.2.1',
+                      table=10,
+                      onlink=True,
+                      family=socket.AF_INET),
+            mock.call(controller.ADD,
+                      oif=idx,
+                      dst='198.51.100.0/24',
+                      gateway='192.0.2.2',
+                      prefsrc='192.0.2.4',
+                      scope='link',
+                      family=socket.AF_INET),
+            mock.call(controller.ADD,
+                      oif=idx,
+                      dst='2001:db8:2::1/128',
+                      gateway='2001:db8::1',
+                      family=socket.AF_INET6)])
+
+        mock_rule.assert_has_calls([
+            mock.call(controller.ADD,
+                      src="203.0.113.1",
+                      src_len=32,
+                      table=20,
+                      family=socket.AF_INET),
+            mock.call(controller.ADD,
+                      src="2001:db8::1",
+                      src_len=128,
+                      table=40,
+                      family=socket.AF_INET6)])
+
+        mock_check_output.assert_has_calls([
+            mock.call([consts.NFT_CMD, '-o', '-f', consts.NFT_RULES_FILE],
+                      stderr=subprocess.STDOUT),
+            mock.call(["post-up", "fake-eth1"])
+        ])
+
+        mock_nftable.assert_called_once_with('fake-eth1', [])
+
+    @mock.patch('pyroute2.IPRoute.rule', create=True)
+    @mock.patch('pyroute2.IPRoute.get_routes', create=True)
+    @mock.patch('pyroute2.IPRoute.addr', create=True)
+    @mock.patch('pyroute2.IPRoute.link', create=True)
+    @mock.patch('pyroute2.IPRoute.get_links', create=True)
+    @mock.patch('pyroute2.IPRoute.link_lookup', create=True)
+    @mock.patch('pyroute2.IPRoute.get_rules', create=True)
+    @mock.patch('subprocess.check_output')
+    def test_up_backend(self, mock_check_output, mock_get_rules,
+                        mock_link_lookup, mock_get_links, mock_link, mock_addr,
+                        mock_get_routes, mock_rule):
+        iface = interface_file.InterfaceFile(
+            name="eth1",
+            if_type="backend",
+            mtu=1450,
+            addresses=[{
+                consts.ADDRESS: '1.2.3.4',
+                consts.PREFIXLEN: 24
+            }],
+            routes=[],
+            rules=[],
+            scripts={
+                consts.IFACE_UP: [{
+                    consts.COMMAND: "post-up eth1"
+                }],
+                consts.IFACE_DOWN: [{
+                    consts.COMMAND: "post-down eth1"
+                }],
+            })
+
+        idx = mock.MagicMock()
+        mock_link_lookup.return_value = [idx]
+
+        mock_get_links.return_value = [{
+            consts.STATE: consts.IFACE_DOWN
+        }]
+        mock_get_rules.return_value = [{
+            'src_len': 32,
+            'attrs': {
+                'FRA_SRC': '1.1.1.1',
+                'FRA_TABLE': 20,
+                'FRA_PROTOCOL': 0
+            }
+        }]
+
+        controller = interface.InterfaceController()
+        controller.up(iface)
+
+        mock_link.assert_called_once_with(
+            controller.SET,
+            index=idx,
+            state=consts.IFACE_UP,
+            mtu=1450)
+
+        mock_addr.assert_has_calls([
+            mock.call(controller.ADD,
+                      index=idx,
+                      address='1.2.3.4',
+                      prefixlen=24,
+                      family=socket.AF_INET),
+        ])
+
+        mock_get_routes.assert_called_once_with(oif=idx)
+
+        # for 'backend' iface, we don't update the rules
+        mock_rule.assert_not_called()
+
+        mock_check_output.assert_has_calls([
+            mock.call(["post-up", "eth1"])
+        ])
+
+    @mock.patch('pyroute2.IPRoute.rule', create=True)
+    @mock.patch('pyroute2.IPRoute.route', create=True)
+    @mock.patch('pyroute2.IPRoute.addr', create=True)
+    @mock.patch('pyroute2.IPRoute.link', create=True)
+    @mock.patch('pyroute2.IPRoute.get_links', create=True)
+    @mock.patch('pyroute2.IPRoute.get_rules', create=True)
+    @mock.patch('pyroute2.IPRoute.get_routes', create=True)
+    @mock.patch('pyroute2.IPRoute.get_addr', create=True)
+    @mock.patch('pyroute2.IPRoute.link_lookup', create=True)
     @mock.patch('subprocess.check_output')
     @mock.patch('octavia.amphorae.backends.utils.interface.'
                 'InterfaceController._wait_tentative')
@@ -463,6 +676,7 @@ class TestInterface(base.TestCase):
                        mock_route, mock_rule):
         iface = interface_file.InterfaceFile(
             name="eth1",
+            if_type="vip",
             mtu=1450,
             addresses=[{
                 consts.ADDRESS: '1.2.3.4',
@@ -638,17 +852,19 @@ class TestInterface(base.TestCase):
                       table=254,
                       family=socket.AF_INET)])
 
-        mock_check_output.assert_not_called()
+        mock_check_output.assert_has_calls([
+            mock.call(["post-up", "eth1"])
+        ])
 
-    @mock.patch('pyroute2.IPRoute.rule')
-    @mock.patch('pyroute2.IPRoute.route')
-    @mock.patch('pyroute2.IPRoute.addr')
-    @mock.patch('pyroute2.IPRoute.link')
-    @mock.patch('pyroute2.IPRoute.get_links')
-    @mock.patch('pyroute2.IPRoute.get_rules')
-    @mock.patch('pyroute2.IPRoute.get_routes')
-    @mock.patch('pyroute2.IPRoute.get_addr')
-    @mock.patch('pyroute2.IPRoute.link_lookup')
+    @mock.patch('pyroute2.IPRoute.rule', create=True)
+    @mock.patch('pyroute2.IPRoute.route', create=True)
+    @mock.patch('pyroute2.IPRoute.addr', create=True)
+    @mock.patch('pyroute2.IPRoute.link', create=True)
+    @mock.patch('pyroute2.IPRoute.get_links', create=True)
+    @mock.patch('pyroute2.IPRoute.get_rules', create=True)
+    @mock.patch('pyroute2.IPRoute.get_routes', create=True)
+    @mock.patch('pyroute2.IPRoute.get_addr', create=True)
+    @mock.patch('pyroute2.IPRoute.link_lookup', create=True)
     @mock.patch('subprocess.check_output')
     @mock.patch('octavia.amphorae.backends.utils.interface.'
                 'InterfaceController._wait_tentative')
@@ -658,6 +874,7 @@ class TestInterface(base.TestCase):
                      mock_route, mock_rule):
         iface = interface_file.InterfaceFile(
             name="eth1",
+            if_type="vip",
             mtu=1450,
             addresses=[{
                 consts.DHCP: True,
@@ -697,31 +914,31 @@ class TestInterface(base.TestCase):
         mock_check_output.assert_has_calls([
             mock.call(["/sbin/dhclient",
                        "-lf",
-                       "/var/lib/dhclient/dhclient-{}.leases".format(
-                           iface.name),
+                       f"/var/lib/dhclient/dhclient-{iface.name}.leases",
                        "-pf",
-                       "/run/dhclient-{}.pid".format(iface.name),
-                       iface.name], stderr=-2),
+                       f"/run/dhclient-{iface.name}.pid",
+                       iface.name], stderr=subprocess.STDOUT),
             mock.call(["/sbin/sysctl", "-w",
-                       "net.ipv6.conf.{}.accept_ra=2".format(iface.name)],
-                      stderr=-2),
+                       f"net.ipv6.conf.{iface.name}.accept_ra=2"],
+                      stderr=subprocess.STDOUT),
             mock.call(["/sbin/sysctl", "-w",
-                       "net.ipv6.conf.{}.autoconf=1".format(iface.name)],
-                      stderr=-2),
+                       f"net.ipv6.conf.{iface.name}.autoconf=1"],
+                      stderr=subprocess.STDOUT),
             mock.call(["post-up", iface.name])
         ])
 
-    @mock.patch('pyroute2.IPRoute.rule')
-    @mock.patch('pyroute2.IPRoute.route')
-    @mock.patch('pyroute2.IPRoute.addr')
-    @mock.patch('pyroute2.IPRoute.link')
-    @mock.patch('pyroute2.IPRoute.get_links')
-    @mock.patch('pyroute2.IPRoute.link_lookup')
+    @mock.patch('pyroute2.IPRoute.rule', create=True)
+    @mock.patch('pyroute2.IPRoute.route', create=True)
+    @mock.patch('pyroute2.IPRoute.addr', create=True)
+    @mock.patch('pyroute2.IPRoute.link', create=True)
+    @mock.patch('pyroute2.IPRoute.get_links', create=True)
+    @mock.patch('pyroute2.IPRoute.link_lookup', create=True)
     @mock.patch('subprocess.check_output')
     def test_down(self, mock_check_output, mock_link_lookup, mock_get_links,
                   mock_link, mock_addr, mock_route, mock_rule):
         iface = interface_file.InterfaceFile(
             name="eth1",
+            if_type="vip",
             mtu=1450,
             addresses=[{
                 consts.ADDRESS: '1.2.3.4',
@@ -835,19 +1052,20 @@ class TestInterface(base.TestCase):
             mock.call(["post-down", "eth1"])
         ])
 
-    @mock.patch('pyroute2.IPRoute.rule')
-    @mock.patch('pyroute2.IPRoute.route')
-    @mock.patch('pyroute2.IPRoute.addr')
-    @mock.patch('pyroute2.IPRoute.flush_addr')
-    @mock.patch('pyroute2.IPRoute.link')
-    @mock.patch('pyroute2.IPRoute.get_links')
-    @mock.patch('pyroute2.IPRoute.link_lookup')
+    @mock.patch('pyroute2.IPRoute.rule', create=True)
+    @mock.patch('pyroute2.IPRoute.route', create=True)
+    @mock.patch('pyroute2.IPRoute.addr', create=True)
+    @mock.patch('pyroute2.IPRoute.flush_addr', create=True)
+    @mock.patch('pyroute2.IPRoute.link', create=True)
+    @mock.patch('pyroute2.IPRoute.get_links', create=True)
+    @mock.patch('pyroute2.IPRoute.link_lookup', create=True)
     @mock.patch('subprocess.check_output')
     def test_down_with_errors(self, mock_check_output, mock_link_lookup,
                               mock_get_links, mock_link, mock_flush_addr,
                               mock_addr, mock_route, mock_rule):
         iface = interface_file.InterfaceFile(
             name="eth1",
+            if_type="vip",
             mtu=1450,
             addresses=[{
                 consts.ADDRESS: '1.2.3.4',
@@ -985,18 +1203,19 @@ class TestInterface(base.TestCase):
             mock.call(["post-down", "eth1"])
         ])
 
-    @mock.patch('pyroute2.IPRoute.rule')
-    @mock.patch('pyroute2.IPRoute.route')
-    @mock.patch('pyroute2.IPRoute.addr')
-    @mock.patch('pyroute2.IPRoute.link')
-    @mock.patch('pyroute2.IPRoute.get_links')
-    @mock.patch('pyroute2.IPRoute.link_lookup')
+    @mock.patch('pyroute2.IPRoute.rule', create=True)
+    @mock.patch('pyroute2.IPRoute.route', create=True)
+    @mock.patch('pyroute2.IPRoute.addr', create=True)
+    @mock.patch('pyroute2.IPRoute.link', create=True)
+    @mock.patch('pyroute2.IPRoute.get_links', create=True)
+    @mock.patch('pyroute2.IPRoute.link_lookup', create=True)
     @mock.patch('subprocess.check_output')
     def test_down_already_down(self, mock_check_output, mock_link_lookup,
                                mock_get_links, mock_link, mock_addr,
                                mock_route, mock_rule):
         iface = interface_file.InterfaceFile(
             name="eth1",
+            if_type="vip",
             mtu=1450,
             addresses=[{
                 consts.ADDRESS: '1.2.3.4',
@@ -1056,19 +1275,20 @@ class TestInterface(base.TestCase):
         mock_rule.assert_not_called()
         mock_check_output.assert_not_called()
 
-    @mock.patch('pyroute2.IPRoute.rule')
-    @mock.patch('pyroute2.IPRoute.route')
-    @mock.patch('pyroute2.IPRoute.addr')
-    @mock.patch('pyroute2.IPRoute.flush_addr')
-    @mock.patch('pyroute2.IPRoute.link')
-    @mock.patch('pyroute2.IPRoute.get_links')
-    @mock.patch('pyroute2.IPRoute.link_lookup')
+    @mock.patch('pyroute2.IPRoute.rule', create=True)
+    @mock.patch('pyroute2.IPRoute.route', create=True)
+    @mock.patch('pyroute2.IPRoute.addr', create=True)
+    @mock.patch('pyroute2.IPRoute.flush_addr', create=True)
+    @mock.patch('pyroute2.IPRoute.link', create=True)
+    @mock.patch('pyroute2.IPRoute.get_links', create=True)
+    @mock.patch('pyroute2.IPRoute.link_lookup', create=True)
     @mock.patch('subprocess.check_output')
     def test_down_auto(self, mock_check_output, mock_link_lookup,
                        mock_get_links, mock_link, mock_flush_addr,
                        mock_addr, mock_route, mock_rule):
         iface = interface_file.InterfaceFile(
             name="eth1",
+            if_type="vip",
             mtu=1450,
             addresses=[{
                 consts.DHCP: True,
@@ -1110,17 +1330,16 @@ class TestInterface(base.TestCase):
             mock.call(["/sbin/dhclient",
                        "-r",
                        "-lf",
-                       "/var/lib/dhclient/dhclient-{}.leases".format(
-                           iface.name),
+                       f"/var/lib/dhclient/dhclient-{iface.name}.leases",
                        "-pf",
-                       "/run/dhclient-{}.pid".format(iface.name),
-                       iface.name], stderr=-2),
+                       f"/run/dhclient-{iface.name}.pid",
+                       iface.name], stderr=subprocess.STDOUT),
             mock.call(["/sbin/sysctl", "-w",
-                       "net.ipv6.conf.{}.accept_ra=0".format(iface.name)],
-                      stderr=-2),
+                       f"net.ipv6.conf.{iface.name}.accept_ra=0"],
+                      stderr=subprocess.STDOUT),
             mock.call(["/sbin/sysctl", "-w",
-                       "net.ipv6.conf.{}.autoconf=0".format(iface.name)],
-                      stderr=-2),
+                       f"net.ipv6.conf.{iface.name}.autoconf=0"],
+                      stderr=subprocess.STDOUT),
             mock.call(["post-down", iface.name])
         ])
 
