@@ -22,27 +22,6 @@ class TestHouseKeepingCMD(base.TestCase):
     def setUp(self):
         super().setUp()
 
-    @mock.patch('octavia.cmd.house_keeping.spare_amp_thread_event')
-    @mock.patch('octavia.controller.housekeeping.'
-                'house_keeping.SpareAmphora')
-    def test_spare_amphora_check(self, mock_SpareAmphora,
-                                 spare_amp_thread_event_mock):
-        spare_amp_mock = mock.MagicMock()
-        spare_check_mock = mock.MagicMock()
-        spare_amp_mock.spare_check = spare_check_mock
-        mock_SpareAmphora.return_value = spare_amp_mock
-
-        # mock spare_amp_thread_event.is_set() in the while loop
-        spare_amp_thread_event_mock.is_set = mock.MagicMock()
-        spare_amp_thread_event_mock.is_set.side_effect = [False,
-                                                          Exception('break')]
-
-        self.assertRaisesRegex(Exception, 'break',
-                               house_keeping.spare_amphora_check)
-
-        mock_SpareAmphora.assert_called_once_with()
-        self.assertEqual(1, spare_amp_mock.spare_check.call_count)
-
     @mock.patch('octavia.cmd.house_keeping.db_cleanup_thread_event')
     @mock.patch('octavia.controller.housekeeping.'
                 'house_keeping.DatabaseCleanup')
@@ -111,78 +90,61 @@ class TestHouseKeepingCMD(base.TestCase):
 
     @mock.patch('octavia.cmd.house_keeping.cert_rotate_thread_event')
     @mock.patch('octavia.cmd.house_keeping.db_cleanup_thread_event')
-    @mock.patch('octavia.cmd.house_keeping.spare_amp_thread_event')
     @mock.patch('threading.Thread')
     @mock.patch('octavia.common.service.prepare_service')
     def test_main(self, mock_service, mock_thread,
-                  spare_amp_thread_event_mock,
                   db_cleanup_thread_event_mock,
                   cert_rotate_thread_event_mock):
 
-        spare_amp_thread_mock = mock.MagicMock()
         db_cleanup_thread_mock = mock.MagicMock()
         cert_rotate_thread_mock = mock.MagicMock()
 
-        mock_thread.side_effect = [spare_amp_thread_mock,
-                                   db_cleanup_thread_mock,
+        mock_thread.side_effect = [db_cleanup_thread_mock,
                                    cert_rotate_thread_mock]
 
-        spare_amp_thread_mock.daemon.return_value = True
         db_cleanup_thread_mock.daemon.return_value = True
         cert_rotate_thread_mock.daemon.return_value = True
 
         house_keeping.main()
 
-        spare_amp_thread_mock.start.assert_called_once_with()
         db_cleanup_thread_mock.start.assert_called_once_with()
         cert_rotate_thread_mock.start.assert_called_once_with()
 
-        self.assertTrue(spare_amp_thread_mock.daemon)
         self.assertTrue(db_cleanup_thread_mock.daemon)
         self.assertTrue(cert_rotate_thread_mock.daemon)
 
     @mock.patch('octavia.cmd.house_keeping.cert_rotate_thread_event')
     @mock.patch('octavia.cmd.house_keeping.db_cleanup_thread_event')
-    @mock.patch('octavia.cmd.house_keeping.spare_amp_thread_event')
     @mock.patch('threading.Thread')
     @mock.patch('octavia.common.service.prepare_service')
     def test_main_keyboard_interrupt(self, mock_service, mock_thread,
-                                     spare_amp_thread_event_mock,
                                      db_cleanup_thread_event_mock,
                                      cert_rotate_thread_event_mock):
-        spare_amp_thread_mock = mock.MagicMock()
         db_cleanup_thread_mock = mock.MagicMock()
         cert_rotate_thread_mock = mock.MagicMock()
 
-        mock_thread.side_effect = [spare_amp_thread_mock,
-                                   db_cleanup_thread_mock,
+        mock_thread.side_effect = [db_cleanup_thread_mock,
                                    cert_rotate_thread_mock]
 
-        spare_amp_thread_mock.daemon.return_value = True
         db_cleanup_thread_mock.daemon.return_value = True
         cert_rotate_thread_mock.daemon.return_value = True
 
         mock_join = mock.MagicMock()
         mock_join.side_effect = [KeyboardInterrupt, None]
-        spare_amp_thread_mock.join = mock_join
+        db_cleanup_thread_mock.join = mock_join
 
         house_keeping.main()
 
-        spare_amp_thread_event_mock.set.assert_called_once_with()
-
         db_cleanup_thread_event_mock.set.assert_called_once_with()
 
         cert_rotate_thread_event_mock.set.assert_called_once_with()
 
-        spare_amp_thread_mock.start.assert_called_once_with()
         db_cleanup_thread_mock.start.assert_called_once_with()
         cert_rotate_thread_mock.start.assert_called_once_with()
 
-        self.assertTrue(spare_amp_thread_mock.daemon)
         self.assertTrue(db_cleanup_thread_mock.daemon)
         self.assertTrue(cert_rotate_thread_mock.daemon)
-        self.assertEqual(2, spare_amp_thread_mock.join.call_count)
-        db_cleanup_thread_mock.join.assert_called_once_with()
+        self.assertEqual(2, db_cleanup_thread_mock.join.call_count)
         cert_rotate_thread_mock.join.assert_called_once_with()
 
     @mock.patch('oslo_config.cfg.CONF.mutate_config_files')
