@@ -123,10 +123,8 @@ class TestDatabaseTasksQuota(base.TestCase):
         with mock.patch('octavia.db.api.'
                         'get_session') as mock_get_session_local:
             mock_session = mock.MagicMock()
-            mock_lock_session = mock.MagicMock()
 
-            mock_get_session_local.side_effect = [mock_session,
-                                                  mock_lock_session]
+            mock_get_session_local.return_value = mock_session
 
             if data_model == data_models.Pool:
                 task.revert(test_object, self.zero_pool_child_count, None)
@@ -136,19 +134,17 @@ class TestDatabaseTasksQuota(base.TestCase):
                 task.revert(test_object, None)
 
             mock_check_quota_met.assert_called_once_with(
-                mock_session, mock_lock_session, data_model,
+                mock_session, data_model,
                 project_id)
 
-            mock_lock_session.commit.assert_called_once_with()
+            mock_session.commit.assert_called_once_with()
 
         # revert with rollback
         with mock.patch('octavia.db.api.'
                         'get_session') as mock_get_session_local:
             mock_session = mock.MagicMock()
-            mock_lock_session = mock.MagicMock()
 
-            mock_get_session_local.side_effect = [mock_session,
-                                                  mock_lock_session]
+            mock_get_session_local.return_value = mock_session
 
             mock_check_quota_met.side_effect = (
                 exceptions.OctaviaException('fail'))
@@ -160,7 +156,7 @@ class TestDatabaseTasksQuota(base.TestCase):
             else:
                 task.revert(test_object, None)
 
-            mock_lock_session.rollback.assert_called_once_with()
+            mock_session.rollback.assert_called_once_with()
 
         # revert with db exception
         mock_check_quota_met.reset_mock()
@@ -238,27 +234,22 @@ class TestDatabaseTasksQuota(base.TestCase):
         mock_session.reset_mock()
         with mock.patch('octavia.db.api.'
                         'get_session') as mock_get_session_local:
-            mock_lock_session = mock.MagicMock()
-            mock_get_session_local.side_effect = [mock_session,
-                                                  mock_lock_session,
-                                                  mock_lock_session,
-                                                  mock_lock_session,
-                                                  mock_lock_session]
+            mock_get_session_local.return_value = mock_session
 
             task.revert(project_id, pool_child_count, None)
 
-            calls = [mock.call(mock_session, mock_lock_session,
+            calls = [mock.call(mock_session,
                                data_models.Pool, project_id),
-                     mock.call(mock_session, mock_lock_session,
+                     mock.call(mock_session,
                                data_models.HealthMonitor, project_id),
-                     mock.call(mock_session, mock_lock_session,
+                     mock.call(mock_session,
                                data_models.Member, project_id),
-                     mock.call(mock_session, mock_lock_session,
+                     mock.call(mock_session,
                                data_models.Member, project_id)]
 
             mock_check_quota_met.assert_has_calls(calls)
 
-            self.assertEqual(4, mock_lock_session.commit.call_count)
+            self.assertEqual(4, mock_session.commit.call_count)
 
         # revert with health monitor quota exception
         mock_session.reset_mock()
@@ -266,28 +257,23 @@ class TestDatabaseTasksQuota(base.TestCase):
                                             None]
         with mock.patch('octavia.db.api.'
                         'get_session') as mock_get_session_local:
-            mock_lock_session = mock.MagicMock()
-            mock_get_session_local.side_effect = [mock_session,
-                                                  mock_lock_session,
-                                                  mock_lock_session,
-                                                  mock_lock_session,
-                                                  mock_lock_session]
+            mock_get_session_local.return_value = mock_session
 
             task.revert(project_id, pool_child_count, None)
 
-            calls = [mock.call(mock_session, mock_lock_session,
+            calls = [mock.call(mock_session,
                                data_models.Pool, project_id),
-                     mock.call(mock_session, mock_lock_session,
+                     mock.call(mock_session,
                                data_models.HealthMonitor, project_id),
-                     mock.call(mock_session, mock_lock_session,
+                     mock.call(mock_session,
                                data_models.Member, project_id),
-                     mock.call(mock_session, mock_lock_session,
+                     mock.call(mock_session,
                                data_models.Member, project_id)]
 
             mock_check_quota_met.assert_has_calls(calls)
 
-            self.assertEqual(3, mock_lock_session.commit.call_count)
-            self.assertEqual(1, mock_lock_session.rollback.call_count)
+            self.assertEqual(3, mock_session.commit.call_count)
+            self.assertEqual(1, mock_session.rollback.call_count)
 
         # revert with member quota exception
         mock_session.reset_mock()
@@ -295,72 +281,43 @@ class TestDatabaseTasksQuota(base.TestCase):
                                             Exception('fail')]
         with mock.patch('octavia.db.api.'
                         'get_session') as mock_get_session_local:
-            mock_lock_session = mock.MagicMock()
-            mock_get_session_local.side_effect = [mock_session,
-                                                  mock_lock_session,
-                                                  mock_lock_session,
-                                                  mock_lock_session,
-                                                  mock_lock_session]
+            mock_get_session_local.return_value = mock_session
 
             task.revert(project_id, pool_child_count, None)
 
-            calls = [mock.call(mock_session, mock_lock_session,
+            calls = [mock.call(mock_session,
                                data_models.Pool, project_id),
-                     mock.call(mock_session, mock_lock_session,
+                     mock.call(mock_session,
                                data_models.HealthMonitor, project_id),
-                     mock.call(mock_session, mock_lock_session,
+                     mock.call(mock_session,
                                data_models.Member, project_id),
-                     mock.call(mock_session, mock_lock_session,
+                     mock.call(mock_session,
                                data_models.Member, project_id)]
 
             mock_check_quota_met.assert_has_calls(calls)
 
-            self.assertEqual(3, mock_lock_session.commit.call_count)
-            self.assertEqual(1, mock_lock_session.rollback.call_count)
+            self.assertEqual(3, mock_session.commit.call_count)
+            self.assertEqual(1, mock_session.rollback.call_count)
 
-    @mock.patch('octavia.db.api.get_session')
-    @mock.patch('octavia.db.repositories.PoolRepository.get')
+    @mock.patch('octavia.db.api.session')
+    @mock.patch('octavia.db.repositories.PoolRepository.get_children_count')
     def test_count_pool_children_for_quota(self, repo_mock, session_mock):
         project_id = uuidutils.generate_uuid()
-        member1 = data_models.Member(id=1, project_id=project_id)
-        member2 = data_models.Member(id=2, project_id=project_id)
-        healtmon = data_models.HealthMonitor(id=1, project_id=project_id)
-        pool_no_children = data_models.Pool(id=1, project_id=project_id)
-        pool_1_mem = data_models.Pool(id=1, project_id=project_id,
-                                      members=[member1])
-        pool_hm = data_models.Pool(id=1, project_id=project_id,
-                                   health_monitor=healtmon)
-        pool_hm_2_mem = data_models.Pool(id=1, project_id=project_id,
-                                         health_monitor=healtmon,
-                                         members=[member1, member2])
+        pool = data_models.Pool(id=1, project_id=project_id)
 
         task = database_tasks.CountPoolChildrenForQuota()
 
         # Test pool with no children
         repo_mock.reset_mock()
-        repo_mock.return_value = pool_no_children
-        result = task.execute(pool_no_children.id)
+        repo_mock.return_value = (0, 0)
+        result = task.execute(pool.id)
 
         self.assertEqual({'HM': 0, 'member': 0}, result)
 
-        # Test pool with one member
-        repo_mock.reset_mock()
-        repo_mock.return_value = pool_1_mem
-        result = task.execute(pool_1_mem.id)
-
-        self.assertEqual({'HM': 0, 'member': 1}, result)
-
-        # Test pool with health monitor and no members
-        repo_mock.reset_mock()
-        repo_mock.return_value = pool_hm
-        result = task.execute(pool_hm.id)
-
-        self.assertEqual({'HM': 1, 'member': 0}, result)
-
         # Test pool with health monitor and two members
         repo_mock.reset_mock()
-        repo_mock.return_value = pool_hm_2_mem
-        result = task.execute(pool_hm_2_mem.id)
+        repo_mock.return_value = (1, 2)
+        result = task.execute(pool.id)
 
         self.assertEqual({'HM': 1, 'member': 2}, result)
 
@@ -409,24 +366,20 @@ class TestDatabaseTasksQuota(base.TestCase):
         mock_session.reset_mock()
         with mock.patch('octavia.db.api.'
                         'get_session') as mock_get_session_local:
-            mock_lock_session = mock.MagicMock()
-            mock_get_session_local.side_effect = [mock_session,
-                                                  mock_lock_session,
-                                                  mock_lock_session,
-                                                  mock_lock_session]
+            mock_get_session_local.return_value = mock_session
 
             task.revert(test_object, None)
 
-            calls = [mock.call(mock_session, mock_lock_session,
+            calls = [mock.call(mock_session,
                                data_models.L7Policy, project_id),
-                     mock.call(mock_session, mock_lock_session,
+                     mock.call(mock_session,
                                data_models.L7Rule, project_id),
-                     mock.call(mock_session, mock_lock_session,
+                     mock.call(mock_session,
                                data_models.L7Rule, project_id)]
 
             mock_check_quota_met.assert_has_calls(calls)
 
-            self.assertEqual(3, mock_lock_session.commit.call_count)
+            self.assertEqual(3, mock_session.commit.call_count)
 
         # revert with l7rule quota exception
         mock_session.reset_mock()
@@ -434,25 +387,21 @@ class TestDatabaseTasksQuota(base.TestCase):
                                             Exception('fail')]
         with mock.patch('octavia.db.api.'
                         'get_session') as mock_get_session_local:
-            mock_lock_session = mock.MagicMock()
-            mock_get_session_local.side_effect = [mock_session,
-                                                  mock_lock_session,
-                                                  mock_lock_session,
-                                                  mock_lock_session]
+            mock_get_session_local.return_value = mock_session
 
             task.revert(test_object, None)
 
-            calls = [mock.call(mock_session, mock_lock_session,
+            calls = [mock.call(mock_session,
                                data_models.L7Policy, project_id),
-                     mock.call(mock_session, mock_lock_session,
+                     mock.call(mock_session,
                                data_models.L7Rule, project_id),
-                     mock.call(mock_session, mock_lock_session,
+                     mock.call(mock_session,
                                data_models.L7Rule, project_id)]
 
             mock_check_quota_met.assert_has_calls(calls)
 
-            self.assertEqual(2, mock_lock_session.commit.call_count)
-            self.assertEqual(1, mock_lock_session.rollback.call_count)
+            self.assertEqual(2, mock_session.commit.call_count)
+            self.assertEqual(1, mock_session.rollback.call_count)
 
     def test_decrement_l7rule_quota(self):
         project_id = uuidutils.generate_uuid()
